# ERGMs FOR WITHIN-HOUSEHOLD CONTACT NETWORKS
# UNCONSTRAINED OPTIMIZATION
#
# Based on:
#   Author: Nele Goeyvaerts
#   Last update: 05/07/2017
# 
# Last update: 14/06/2016
###################################################

rm(list = ls())

# Set working directory (home / simlab)
wd <- "D:/Eva/UHasselt/CenStat/Projects/Nele - household networks/"

# Load required libraries
library(statnet)
library(ergm.userterms) #modify this folder and install via the command prompt
#toBibtex(citation("statnet"))
#toBibtex(citation("ergm"))
library(miscFuncs)
library(coda)
library(xtable)
library(latticeExtra)
library(Matrix)		# block diagonal matrix
library(MASS)		# truehist function

# Define functions logit and expit
logit <- function(p){log(p/(1-p))}	
expit <- function(x){exp(x)/(1+exp(x))}	


#########################
# READ HH NETWORK DATA	#   
#########################

setwd(paste(wd, "programs/R code", sep = ""))

# Load workspace
#load("all_undirected.RData")
load("close_undirected.RData")	# physical contacts only

# Choose: all contacts, weekday contacts, weekend contacts
#choice <- "all_contacts"
choice <- "week_contacts"
#choice <- "weekend_contacts"

# HH network
HH_global <- inputData$HH_global
print(HH_global)
list.edge.attributes(HH_global)

# Participant and contact data
pData <- inputData$pData
names(pData)

# Plot network data
setwd(paste(wd, "Eva/Results", sep = ""))
windows(record=T)
par(mar=c(0.5,4.1,0.5,2.1))
plot(HH_global, vertex.cex = 0.4, vertex.col = "hh_size", usearrows = usearrows, mode = "fruchtermanreingold", displayisolates = FALSE)
hhsize.vec <- sort(unique(HH_global %v% "hh_size"))
legend("topright", legend = hhsize.vec, fill = hhsize.vec)
savePlot(filename = "networks_close_undirected2", type = "eps", restoreConsole = TRUE)
dev.off()

# Plot network data per HH size
size = sort(unique(HH_global %v% "hh_size"))
windows(record=T,10,5)
par(mar=c(0.5,4.1,0.5,2.1),mfrow=c(2,3))
for (i in 1:length(size)){
HH_size <- HH_global %s% which(HH_global %v% "hh_size" == size[i])
plot(HH_size, vertex.cex = 0.8, vertex.col = size[i], usearrows = usearrows, mode = "fruchtermanreingold", displayisolates = FALSE)
legend("topright", legend = size[i], fill = size[i])
}
savePlot(filename = "networks_close_undirected_size", type = "pdf", restoreConsole = TRUE)
savePlot(filename = "networks_close_undirected_size", type = "eps", restoreConsole = TRUE)
dev.off()



## ADD WEEKEND INDICATOR	   
############################

table(pData$dayofweek)
pData$weekend <- ifelse(pData$dayofweek %in% c(6,7), 1, 0)
pData$weekend[pData$dayofweek == 8] <- NA
tab <- table(pData$weekend, useNA="ifany")
tab		# Note: 1 HH with missing recording date

# Create vertex attribute
part_id <- HH_global %v% "part_id"
length(part_id)
weekend <- pData$weekend[match(part_id, pData$part_id)]
length(weekend)
set.vertex.attribute(HH_global, "weekend", weekend)
tab <- table(HH_global %v% "weekend", useNA="ifany")
tab 		# Note: the HH with missing recording date is a non-traditional HH (and thus excluded)


## SELECT CONTACT NETWORKS OF INTEREST	   
#######################################

if(choice == "week_contacts"){
	HH_global <- HH_global %s% which(weekend == 0)
	}
if(choice == "weekend_contacts"){
	HH_global <- HH_global %s% which(weekend == 1)
	}
print(HH_global) # all: nr vertices = 1266, week: nr vertices = 898, weekend:  nr vertices = 364


## EXPLORE VERTEX AND EDGE ATTRIBUTES	   
#######################################

#setwd(paste(wd, "results/hh survey data description/figures/", choice, sep = ""))

## Vertex attributes

list.vertex.attributes(HH_global)
age <- HH_global %v% "age"
hist(age, main = "", xlab = "age")
hist(age[age <= 20], main = "", xlab = "age", breaks = 20)
#savePlot(filename = "hist_age_0_20.eps", type = "eps", restoreConsole = TRUE)
#dev.off()
table(HH_global %v% "gender", useNA = "ifany")
table(HH_global %v% "hh_composition", useNA = "ifany")
length(unique(HH_global %v% "hh_id"))		# n = 319
table(HH_global %v% "hh_role", useNA = "ifany")
table(HH_global %v% "hh_size", useNA = "ifany")	
table(HH_global %v% "hh_traditional", useNA = "ifany")
table(HH_global %v% "na", useNA = "ifany")
length(unique(HH_global %v% "part_id"))
table(HH_global %v% "version", useNA = "ifany")	
# Check that part_id and vertex.names are identical:
cbind(HH_global %v% "part_id", HH_global %v% "vertex.names")[1:20,]


## Add vertex attributes

# Indicator for large households (>= 5 members)
large_hh <- HH_global %v% "hh_size" >= 5
set.vertex.attribute(HH_global, "large_hh", large_hh)
# Check variable
testvar <- HH_global %v% "large_hh"
table(testvar)
hh_size <- HH_global %v% "hh_size"
table(hh_size[testvar == TRUE])		# should display HHs of size >=5
table(hh_size[testvar == FALSE])		# should display HHs of size <5

# Indicator for households with >= 6 members
large_hh_6 <- HH_global %v% "hh_size" >= 6
set.vertex.attribute(HH_global, "large_hh_6", large_hh_6)
# Check variable
testvar <- HH_global %v% "large_hh_6"
table(testvar)
hh_size <- HH_global %v% "hh_size"
table(hh_size[testvar == TRUE]) 	# should display HHs of size >=6
table(hh_size[testvar == FALSE])	# should display HHs of size <6

# Indicator for small households (<= 3 members)
small_hh <- HH_global %v% "hh_size" <= 3
set.vertex.attribute(HH_global, "small_hh", small_hh)
# Check variable
testvar <- HH_global %v% "small_hh"
table(testvar)
test <- HH_global %s% which(testvar == TRUE)
print(test)
table(test %v% "hh_size", useNA = "ifany")	

# Check indicator for small + large households
tab <- table(HH_global %v% "small_hh", HH_global %v% "large_hh")
tab
sum(tab)

# Indicator for households of size 2
size2_hh <- HH_global %v% "hh_size" == 2
set.vertex.attribute(HH_global, "size2_hh", size2_hh)
# Check variable
testvar <- HH_global %v% "size2_hh"
table(testvar)
test <- HH_global %s% which(testvar == TRUE)
print(test)
table(test %v% "hh_size", useNA = "ifany")

# Categorical variable based on "hh_role" to distinguish male and female children
table(HH_global %v% "hh_role")
hh_role_detail <- HH_global %v% "hh_role"
gender <- HH_global %v% "gender"
hh_role_detail[hh_role_detail == "child" & gender == 1] <- "girl"
hh_role_detail[hh_role_detail == "child" & gender == 0] <- "boy"
set.vertex.attribute(HH_global, "hh_role_detail", hh_role_detail)
table(HH_global %v% "hh_role_detail")

# Indicator for children
role <- HH_global %v% "hh_role"
child <- role == "child"
set.vertex.attribute(HH_global, "child", child)
table(HH_global %v% "child")
adult <- role != "child"
set.vertex.attribute(HH_global, "adult", adult)
table(HH_global %v% "adult")

# Log-transform of age = log(age+1)
age <- HH_global %v% "age"
set.vertex.attribute(HH_global, "log_age", log(age+1))
hist(HH_global %v% "log_age")


## Edge attributes

list.edge.attributes(HH_global)
table(HH_global %e% "duration", useNA = "ifany")
table(HH_global %e% "frequency", useNA = "ifany")
unique(HH_global %e% "hh_id")
table(HH_global %e% "hh_size", useNA = "ifany")
table(HH_global %e% "location", useNA = "ifany")
table(HH_global %e% "na", useNA = "ifany")
table(HH_global %e% "touch", useNA = "ifany")


## EXCLUDE NON-TRADITIONAL HOUSEHOLDS	   
########################################

table(HH_global %v% "hh_traditional", useNA = "ifany")
# There are 2 non-traditional households: 
# - household of size 3 with 2 female parents
# - household of size 4 with presumably a grandparent living in with the parents and their child.

# Keep traditional HH
hh_traditional <- HH_global %v% "hh_traditional"
HH_global <- HH_global %s% which(hh_traditional == 1)
print(HH_global)		# n = 1259
length(unique(HH_global %v% "hh_id"))		# n = 316 (all), 225 (week), 91 (weekend)


## Create HH network with complete HH mixing 
#############################################

# Have a look at the adjacency matrix
adjacencyMat <- as.sociomatrix(HH_global)
dim(adjacencyMat)
contour(adjacencyMat)
contour(adjacencyMat[1:100,1:100])

# Create a block diagonal matrix representing households
id <- HH_global %v% "vertex.names"
hh_id <- HH_global %v% "hh_id"
hh_size <- HH_global %v% "hh_size"
hh_id_unique <- hh_id[!duplicated(hh_id)]
id_order <- NULL
for (i in 1:length(hh_id_unique)){
  id_order <- c(id_order, id[hh_id == hh_id_unique[i]])
}
hh_size_unique <- hh_size[!duplicated(hh_id)]
blockMat <- bdiag(mapply(matrix, hh_size_unique, hh_size_unique, data = 1))
dim(blockMat)

## Ordering to match the order of individuals in the network --> corrected 09/08/2016
blockMat.row = matrix(NA,dim(blockMat)[1],dim(blockMat)[2])
for (i in 1:dim(blockMat)[1]){
  blockMat.row[i,] = blockMat[id_order==id[i],]
}
blockMat.order = matrix(NA,dim(blockMat)[1],dim(blockMat)[2])
for (i in 1:dim(blockMat)[2]){
  blockMat.order[,i] = blockMat.row[,id_order==id[i]]
}
dim(blockMat.order)

# Create a new network of complete households
HH_complete <- HH_global
print(HH_complete)
HH_complete[,] <- blockMat.order
print(HH_complete)		# total edges = 2004

# Check number of edges
sum(choose(hh_size_unique, 2))

# Check whether constraint of between-HH mixing is satisfied
edges <- summary(HH_complete ~ edges)
HH_edges <- summary(HH_complete ~ nodematch("hh_id"))
edges == HH_edges

# Save network in programs folder
setwd(paste(wd, "Eva/Results/", sep = ""))
save(HH_complete, file = "HH_complete.RData")


###########################
# NETWORK CHARACTERISTICS #
###########################

# Component size distribution (sna)
table(component.dist(HH_global)$csize)

# Degree distribution (sna)
table(degree(HH_global, gmode="digraph", cmode="indegree"))
table(degree(HH_global, gmode="digraph", cmode="outdegree"))
table(degree(HH_global, gmode="digraph", "freeman")) # default: total (Freeman) degree

# Degree distribution for HHs of a specific size (sna)
hhsize <- HH_global %v% "hh_size"
chooseSize <- 6
table(degree(HH_global, nodes=which(hhsize == chooseSize), gmode="digraph", cmode="indegree"))
table(degree(HH_global, nodes=which(hhsize == chooseSize), gmode="digraph", cmode="outdegree"))
table(degree(HH_global, nodes=which(hhsize == chooseSize), gmode="digraph", "freeman")) # default: total (Freeman) degree

# Degree distribution
summary(HH_global ~ degree(0:6))
summary(HH_global ~ meandeg)		# average degree of a node

# Degree distribution by gender
summary(HH_global ~ degree(0:6, "gender"))
 
# Degree distribution by hhsize
degreedist <- matrix(summary(HH_global ~ degree(0:6, "hh_size")), nrow = 7, ncol = 6)	# rows = degree, cols = hhsize
degreedist2 <- cbind(degreedist[,-(5:6)], apply(degreedist[,5:6], 1, sum))
round(apply(c(0:6)*degreedist2, 2, sum)/apply(degreedist2, 2, sum), 2)				# average degree by hhsize				
round(sum(c(0:6)*degreedist2)/sum(degreedist2), 2)							# average degree (overall)	

# Degree distribution by role
degreedist <- matrix(summary(HH_global ~ degree(0:6, "hh_role")), nrow = 7, ncol = 3)	# rows = degree, cols = role
round(apply(c(0:6)*degreedist, 2, sum)/apply(degreedist, 2, sum), 2)				# average degree by role				
# Note: this is biased because larger HHs have more children	

# Number of edges and triangles
summary(HH_global ~ edges + triangle)

# Mixing matrix by hh_id (not working)
#hhmatrix <- mixingmatrix(HH_global, "hh_id") # does not return a matrix, no help documentation, internal function not to be used

# Mixing matrix by gender
mixingmatrix(HH_global, "gender")


####################################
# NETWORK STATISTICS USED IN ERGMs #
####################################

# Total number of contacts
summary(HH_global ~ edges)

# Total number of within-HH contacts
summary(HH_global ~ nodematch("hh_id"))

# Total number of ch-ch, ch-mo, ch-fa, mo-fa contacts
summary(HH_global ~ nodemix("hh_role")) 	
summary(HH_global ~ nodemix("hh_role", base = c(3,6))) 
summary(HH_global ~ nodemix("hh_role", base = c(1,3,6))) 	
summary(HH_global ~ nodemix("hh_role", base = c(3,5,6))) 			
sum(summary(HH_global ~ nodemix("hh_role", base = c(3,6))))

# Total number of contacts made by children, mothers and fathers
summary(HH_global ~ nodefactor("hh_role")) 	
summary(HH_global ~ nodefactor("hh_role", base = 0)) 
# Total number of contacts made by children
summary(HH_global ~ nodefactor("hh_role", base = c(2,3))) 

# Main effect of household size
summary(HH_global ~ nodecov("hh_size")) 	

# Total number of contacts in large households (>= 5 members)
nr_contacts_hhsize <- summary(HH_global ~ nodefactor("hh_size", base = 0)) 	
nr_contacts_hhsize
sum(nr_contacts_hhsize)/2		# total number of edges
nr_contacts_large_hh <- summary(HH_global ~ nodefactor("large_hh")) 	
nr_contacts_large_hh 
sum(nr_contacts_large_hh)/2

# Total number of contacts in small households (<= 3 members)
nr_contacts_small_hh <- summary(HH_global ~ nodefactor("small_hh")) 	
nr_contacts_small_hh 
sum(nr_contacts_small_hh)/2

# Total number of isolates
summary(HH_global ~ isolates) 

# Total number of female-female and male-male contacts in children
summary(HH_global ~ nodemix("hh_role_detail", base = c(2:5,7:10)))
summary(HH_global ~ nodemix("hh_role_detail", base = c(2:3,5,7:10)))

# Age assortative mixing
summary(HH_global ~ nodematch("age")) # equal to smalldiff("age", 0)
summary(HH_global ~ absdiff("age"))  
summary(HH_global ~ smalldiff("age", 2)) 

# Age effects on mixing between children
summary(HH_global ~ nodecov("age"))		# ages are summed over all edges 
summary(HH_global ~ nodecovstrat("age", "child"))		# ages are summed only for links between children 
# Test:
summary(HH_global ~ nodecovstrat("age", "adult"))		# ages are summed only for links between adults 

# Total number of 2-stars
summary(HH_global ~ kstar(2)) 	

# Percentage of triangles
summary(HH_global ~ tripercent) 	# equivalent to triadcensus.3/(triadcensus.3+triadcensus.2)
summary(HH_global ~ tripercent("hh_id")) 	

# Total number of triangles
summary(HH_global ~ triangle) 	
summary(HH_global ~ triangle("hh_id")) 		
summary(HH_global ~ triangle("hh_size", diff = TRUE)) 		

# Total number of triads per observed number of edges
summary(HH_global ~ triadcensus(0:3)) 
summary(HH_global ~ triadcensus(2:3)) 
summary(HH_global ~ triangle)		# equivalent to triadcensus for 3 observed edges 

# GWDSP and GWESP
summary(HH_global ~ gwdsp(0.5, fixed = TRUE)) 
summary(HH_global ~ gwesp(0.5, fixed = TRUE)) 

# Note: ERGM term 'asymmetric' can be used to count non-reciprocal contacts in the directed networks


## CLUSTERING BY HOUSEHOLD SIZE (NOT FOR SIZE 2)
#####################################################

# Percentage of triangles (tripercent) or mean correlation coefficient
tripercent <- summary(HH_global ~ tripercent("hh_size", diff = TRUE))	# per HH size
round(tripercent, 0)
round(summary(HH_global ~ tripercent("large_hh_6", diff = TRUE)), 0)	# HH size >=6

# Proportion of observed versus potential triangles
triangles <- summary(HH_global ~ triangle("hh_size", diff = TRUE)) 
hh_size <- HH_global %v% "hh_size"
sampleSize <- table(hh_size)/sort(unique(hh_size))	# Number of HHs per HH size (sample sizes)
completeTriangles <- choose(sort(unique(hh_size)),3)
potentialTriangles <- sampleSize*completeTriangles
round(triangles/potentialTriangles, 2)					# per HH size
round(sum(triangles[5:6])/sum(potentialTriangles[5:6]), 2)		# HH size >=6
round(sum(triangles)/sum(potentialTriangles), 2)			# Total

# Clustering coefficient
# Notes: 
# The opentriad term counts the number of 2-stars minus three times the number of triangles in the network
# however, no attribute option implemented 
# kstar(.) has an atrtibute option, but no diff option
open2stars <- round(1/((tripercent/100)/triangles) - triangles)
clustercoef <- triangles/(triangles + 1/3*open2stars)
round(clustercoef, 2)											# per HH size
round(sum(triangles[5:6])/(sum(triangles[5:6]) + 1/3*sum(open2stars[5:6])), 2)	# HH size >=6
round(sum(triangles)/(sum(triangles) + 1/3*sum(open2stars[2:6])), 2)			# Total

# Check: total
triangles <- summary(HH_global ~ triangle) 
stars2 <- summary(HH_global ~ kstar(2)) 
opentriads <- stars2 - 3*triangles
triangles/(triangles+opentriads)	# tripercent
summary(HH_global ~ tripercent)				
3*triangles/(3*triangles+opentriads)	# clustering coefficient


## TEST SELF-SPECIFIED NETWORK STATISTICS	   
###########################################

# Nodecovstrat and nodelogcovstrat

# Subset of households size 2
testvar <- HH_global %v% "size2_hh"
table(testvar)
test <- HH_global %s% which(testvar == TRUE)
print(test)
table(test %v% "hh_size", useNA = "ifany")

sum(test %v% "age")
summary(HH_global ~ nodecovstrat("age", "size2_hh"))
summary(HH_global ~ nodelogcovstrat("age", "size2_hh"))

summary(test ~ nodecovstrat("age", "child"))	# should be zero as only child-parent contacts are occurring in hhs of size 2
summary(test ~ nodelogcovstrat("age", "child"))	# should be zero as only child-parent contacts are occurring in hhs of size 2

summary(HH_global ~ nodecovstrat("age", "child"))
summary(HH_global ~ nodelogcovstrat("age", "child"))
summary(HH_global ~ nodecovstrat("log_age", "child"))

summary(HH_global ~ nodecovstrat("age", "adult"))
summary(HH_global ~ nodelogcovstrat("age", "adult"))
summary(HH_global ~ nodecovstrat("log_age", "adult"))

# Trianglestrat
summary(HH_global ~ triangle) 	
summary(HH_global ~ triangle("hh_id")) 	
summary(HH_global ~ triangle("large_hh", diff = TRUE)) 	
summary(HH_global ~ trianglestrat("large_hh", diff = TRUE, keep = 2)) 	
summary(HH_global ~ trianglestrat("small_hh", diff = TRUE)) 			
summary(HH_global ~ trianglestrat("small_hh", diff = TRUE, keep = 2)) 		


## Save network data and model
##############################

setwd(paste(wd, "Eva/Results/",sep = ""))
#save(HH_global, file = "HH_network.RData")


#######################
# UNCONSTRAINED ERGMs #
#######################

## Set directory for model output
##################################
setwd(paste(wd, "Eva/Results/ERGM/", choice, sep = ""))

## Set ERGM control options
##################################
control.choice <- control.ergm(force.main = TRUE, MCMC.prop.weights = "TNT"
, MCMC.burnin = 1e+6, MCMC.interval = 1000, MCMC.samplesize = 5e+5
, MCMLE.termination = "Hotelling", MCMLE.maxit = 50, MCMLE.steplength = 0.5
, seed = 10102012)


###############################
# WITH AGE EFFECT IN CHILDREN #
###############################

## Full Model: mix role, small and large hhsize, isolates, gender preference and age mixing in children, 2stars, triangles (including interaction with hhsize)
##############################################################################################################################################################

# # MPLE
# model <- NULL
# model <- ergm(HH_global ~ edges + nodematch("hh_id") 
# + nodemix("hh_role", base = c(3,6,1))
# + nodemix("hh_role_detail", base = c(2:5,7:10))
# + nodecovstrat("age", "child")
# + nodefactor("small_hh")
# + nodefactor("large_hh")
# + isolates
# + triangle
# , estimate = "MPLE"
# , verbose = TRUE)
# summary(model)


# Approximate MLE (MCMC)
model <- NULL
ptm <- proc.time()
model <- ergm(HH_global ~ edges + nodematch("hh_id") 
+ nodemix("hh_role", base = c(3,6,1))
+ nodemix("hh_role_detail", base = c(2:5,7:10))
+ nodecovstrat("age", "child")
+ nodefactor("small_hh")
+ nodefactor("large_hh")
+ isolates
+ kstar(2)						
+ triangle
+ trianglestrat("large_hh_6", diff = TRUE, keep = 2)
, control = control.choice, verbose = TRUE)
proc.time()-ptm
summary(model)

# Save and load workspace (data and model)
setwd(paste(wd, "Eva/Results/ERGM/", choice,"/Full model",sep = ""))
#save(HH_global, model, file = "ERGM_role_smallHH_largeHH_isolates_prefmixchildren_agemixchildren_2star_triangle_triangleHH6+.RData")
load("ERGM_role_smallHH_largeHH_isolates_prefmixchildren_agemixchildren_2star_triangle_triangleHH6+.RData")


## Reduced Model: mix role, small and large hhsize, age mixing in children, 2stars, triangles (including interaction with hhsize)
#################################################################################################################################
# # MPLE
# model <- NULL
# model <- ergm(HH_global ~ edges + nodematch("hh_id") 
# + nodemix("hh_role", base = c(3,6,1))
# + nodecovstrat("age", "child")
# + nodefactor("small_hh")
# + nodefactor("large_hh")
# + triangle
# , estimate = "MPLE"
# , verbose = TRUE)
# summary(model)


# Approximate MLE (MCMC)
model <- NULL
ptm <- proc.time()
model <- ergm(HH_global ~ edges + nodematch("hh_id") 
+ nodemix("hh_role", base = c(3,6,1))
+ nodecovstrat("age", "child")
#+ nodefactor("small_hh")
#+ nodefactor("large_hh")
+ kstar(2)						
+ triangle
#+ trianglestrat("large_hh_6", diff = TRUE, keep = 2)
, control = control.choice, verbose = TRUE)
proc.time()-ptm
summary(model)

# Save and load workspace (data and model)

## weekend model
setwd(paste(wd, "Eva/Results/ERGM/", choice,"/Final model",sep = ""))
#save(HH_global, model, file = "ERGM_role_agemixchildren_2star_triangle.RData")
load("ERGM_role_agemixchildren_2star_triangle.RData")

## week model
#save(HH_global, model, file = "ERGM_role_smallHH_largeHH_agemixchildren_2star_triangle_triangleHH6+.RData")
load("ERGM_role_smallHH_largeHH_agemixchildren_2star_triangle_triangleHH6+.RData")


################
# MODEL OUTPUT #
################

summary(model)
model
model$coef#[3:length(model$coef)]
model$covar			# approximate covariance matrix for the MLE
sqrt(diag(model$covar))
model$mc.se			# MCMC standard error estimates
model$iterations		# number of Newton-Raphson iterations required before convergence
model$MCMCtheta		# value of theta used to produce the MCMC sample
model$loglikelihood	# approximate change in log-likelihood in the last iteration
model$gradient		# gradient vector of the approximated loglikelihood evaluated at the maximizer. This vector should be very close to zero.
model$mle.lik		# approximate log-likelihood for the MLE
model$failure 		# did the MCMC estimation fail?
model$degeneracy.value	# score calculated to assess the degree of degeneracy in the model
model$drop			# vector indicating which terms were dropped due to to extreme values of the corresponding statistics on the observed network


## Save LaTeX table with parameter estimates and goodness-of-fit
#####################################################################

# Extract values from output model
parEst <- model$coef
names(parEst)
nrPar <- length(parEst)
standardError <- sqrt(diag(model$covar))
WaldTestPvalue <- 2*pnorm(abs(parEst/standardError), lower.tail = FALSE)
loglik <- model$mle.lik
AIC <- -2*loglik + 2*nrPar
BIC <- -2*loglik + log(choose(network.size(HH_global),2))*nrPar	# n = the number of dyads
# This definition of BIC does not hold under dyadic dependence because the effective sample size 
# can be smaller than the number of dyads (Hunter, Goodreau, Handcock, goodness of fit tech report 2005)

# Create table components 
pars <- cbind(parEst, standardError, WaldTestPvalue)		# parameter estimate, s.e., p-value
gofstats <- matrix(c(loglik, AIC, rep(NA,4)), nrow=2)
results <- rbind(pars, gofstats)
colnames(results) <- c("Estimate","s.e.","p-value")

# All attribute effects considered
# HH size >=5
attributeEffects <- c("Edges", "Within-household edges", "Child-father mixing", "Child-mother mixing", "Father-mother mixing", "Boy-boy mixing", "Girl-girl mixing", "Age effect children", "Small (<=3) households", "Large (>=5) households", "Isolates")

# Without gender preference
#attributeEffects <- attributeEffects[-c(6,7)]
# Without isolates
#attributeEffects <- attributeEffects[-c(11)]
# Without gender preference, isolates
attributeEffects <- attributeEffects[-c(6,7,11)]
# Without gender preference, large HH, isolates
#attributeEffects <- attributeEffects[-c(6,7,10,11)]
# Without gender preference, small HH, large HH, isolates
attributeEffects <- attributeEffects[-c(6,7,9,10,11)]
# Only mixing according to role
#attributeEffects <- attributeEffects[-c(6:11)]

# GOF statistics
gofstatsNames <- c("Loglikelihood", "AIC")

# Base model
# 2-star and triangle
rownames(results) <- c(attributeEffects, "2-stars", "Triangles", gofstatsNames)
# 2-star, triangle and triangles in large HH
rownames(results) <- c(attributeEffects, "2-stars", "Triangles", "Triangles in large (>=6) households", gofstatsNames)

# Display and save table with results
summary(model)
results
latexTable <- xtable(results, align = c("l", rep("r", 3)), digits = 2, caption = "Parameter estimates and Wald test p-values, loglikelihood and AIC.")
print(latexTable, include.rownames = TRUE, file = "results_table.txt")


## Figure interpretation coefficients
#########################################

# Initiate parameters
ages <- 0:15
sumAges <- (2*min(ages)):(2*max(ages))
logMin <- (2*log(min(ages)+1))
logMax <- (2*log(max(ages)+1))
sumLogAges <- seq(logMin, logMax, (logMax-logMin)/length(sumAges))

par1 <- results["Child-father mixing", "Estimate"]
par2 <- results["Child-mother mixing", "Estimate"]
par3 <- results["Father-mother mixing", "Estimate"]
par4 <- results["Age effect children", "Estimate"]

# Model: sum ages
oddsRatio <- function(x1, x2){exp(x1 - x2*sumAges)}
xAges <- sumAges
xlab <- "Sum of age(i) and age(j) for child-child"
# Model: log sum ages
#oddsRatio <- function(x1, x2){exp(x1 - x2*log(sumAges + 1))}
#xAges <- sumAges
#xlab <- "Sum of age(i) and age(j) for child-child"
# Model: log prod ages
#oddsRatio <- function(x1, x2){exp(x1 - x2*sumLogAges)}
#xAges <- sumLogAges
#xlab <- "Sum of log(age(i)+1) and log(age(j)+1) for child-child"

# Figure
windows(record=T)
plot(xAges, oddsRatio(par1, par4), type = "l", xlab = xlab, ylab = "Odds ratio", lwd = 2.5)
lines(xAges, oddsRatio(par2, par4), lwd = 2.5, lty = 2)
lines(xAges, oddsRatio(par3, par4), lwd = 2.5, lty = 4)
abline(h=1, lty = 3, lwd = 1.5)
legend("topleft", c("Ch-Fa vs Ch-Ch  ", "Ch-Mo vs Ch-Ch  ", "Fa-Mo vs Ch-Ch  "), lty = c(1:2,4), lwd = 2.5)
savePlot(filename = "interpretation_coeff.eps", type = "eps", restoreConsole = TRUE)
dev.off()


####################
# MCMC DIAGNOSTICS #
####################

# MCMC diagnostics (returns an error, problem in recent version? -> see help forum statnet)
pdf("model_diagnostics.pdf")
#mcmc.diagnostics(model)
plot(mcmc.diagnostics(model))
dev.off()

# You will see several plots and output.  The plots to the right should look approximately normal. 
# The output tells us three things of interest: 
# 1) The accuracy of the model (r)
# 2) If we used a sufficiently large burn-in
# 3) If we used a sufficiently large sample in the simulation

# Use coda directly
#pdf("model_diagnostics.pdf")
#plot(model$sample, ask = FALSE)
#dev.off()


###################
# GOODNESS OF FIT #
###################

## Load functions and objects for GOF simulation
###################################################
# Set working directory
setwd(paste(wd, "programs/R code", sep = ""))

# Load tableDensity function
source("tableDensity.R")

# Load obsNetworks function
source("obsNetworks.R")

# Load HH network with complete mixing
#load(file = "HH_complete.RData")
#print(HH_complete)		# total edges = 2004


## Set working directory to save simulation results
#####################################################

choice <- "week_contacts"
#choice <- "weekend_contacts"

# Initiate working directory
wdsim <- paste(wd, "Eva/Results/ERGM/", choice, sep = "")
setwd(paste(wdsim, "/Final model", sep = ""))  

## Final model weekend
load("ERGM_role_agemixchildren_2star_triangle.RData")

## Final model week
load("ERGM_role_smallHH_largeHH_agemixchildren_2star_triangle_triangleHH6+.RData")


## Simulate networks from fitted model
########################################

# Choose the number of networks to simulate
nSim <- 1000

# Assign name for output
name <- paste("sim_basis_complete_n_", nSim, sep = "")

# Choose the burnin and number of proposals between sampled statistics
interval <- 1e+6
burnin <- 1e+7 

# Set control options for simulation
control.choice.sim <- control.simulate.ergm(MCMC.burnin = burnin, MCMC.interval = interval, MCMC.runtime.traceplot = FALSE)

# Simulate networks 
# The end of one simulation is used as the start of the next simulation (sequential = TRUE)
# The first simulated Markov chain begins at the observed networks:
# HH_sim <- simulate(model, nsim = nSim, control = control.choice.sim, sequential = TRUE, verbose = TRUE, seed = 1515)


# Save and load simulated networks
# --------------------------------

#save(HH_sim, file = paste(name, ".RData", sep = ""))
load(paste(name, ".RData", sep = ""))
# Total number of simulations
nSim <- length(HH_sim[])
nSim

class(HH_sim)
#print(HH_sim[[1]])

# Check whether constraint of between-HH mixing is satisfied
edges <- summary(HH_sim ~ edges)
HH_edges <- summary(HH_sim ~ nodematch("hh_id"))
sum(edges == HH_edges) == dim(edges)[1]


## Table proportion complete networks and network density
#########################################################


## Observed networks
## -----------------

if (choice == "weekend_contacts"){
	range <- c("3","4","5")
	}else{
	range <- c("2","3","4","5","6")
	}
range_num <- as.numeric(range)
ptm = proc.time()
HH_global_density <- tableDensity(HH_global, range = range)
proc.time()-ptm
HH_global_density.table <- HH_global_density$density.table
HH_global_densities <- HH_global_density$densities
propComplete <- HH_global_density.table$propComplete
density <- HH_global_density.table$density

# Vector of hh sizes
hh_id <- HH_global %v% "hh_id"
hh_size <- HH_global %v% "hh_size"
hh_id_unique <- hh_id[!duplicated(hh_id)]
hh_size_unique <- hh_size[!duplicated(hh_id)]
plot(hh_size_unique, HH_global_densities, xlab = "Household size", ylab = "Network density")

# Proportion of observed versus potential triangles
triangles <- summary(HH_global ~ triangle("hh_size", diff = TRUE)) 
sampleSize <- table(hh_size)/sort(unique(hh_size))				# Number of HHs per HH size (sample sizes)
completeTriangles <- choose(sort(unique(hh_size)),3)
potentialTriangles <- sampleSize*completeTriangles
obsClustering <- triangles/potentialTriangles					# Per HH size
obsClustering_67 <- sum(triangles[5:6])/sum(potentialTriangles[5:6]) 	# HH size >=6
obsClustering_567 <- sum(triangles[4:6])/sum(potentialTriangles[4:6]) 	# HH size >=5
if (choice == "weekend_contacts"){
	obsClustering <- c(obsClustering[-c(1,4:6)], obsClustering_567)
	sampleSize <- c(sampleSize[-c(1,4:6)], sum(sampleSize[4:6]))
	}else{
	obsClustering <- c(obsClustering[-c(1,5:6)], obsClustering_67)
	sampleSize <- c(sampleSize[-c(1,5:6)], sum(sampleSize[5:6]))
	}
obsClustering <- c(obsClustering, sum(triangles)/sum(potentialTriangles))	# Add total
sampleSize <- c(sampleSize, sum(sampleSize))


## Simulated networks
## ------------------

HH_sim_density <- sapply(HH_sim, tableDensity, range = range)
simTriangles <- summary(HH_sim ~ triangle("hh_size", diff = TRUE))	# Number of simulated triangles

nCol <- nSim
nCol
nRow <- length(HH_sim_density[,1]$density.table$HHsize)		
nRow

# Retrieve statistics per simulated set (columns = sim, rows = hhsize)
sim_propComplete <- matrix(NA, nrow = nRow, ncol = nCol)		# Proportion complete
sim_meanDensity <- matrix(NA, nrow = nRow, ncol = nCol)		# Mean density
for (i in 1:nCol){
	sim_propComplete[,i] <- HH_sim_density[,i]$density.table$propComplete
	sim_meanDensity[,i] <- HH_sim_density[,i]$density.table$density
	}

# Plots
k <- dim(sim_propComplete)[1]
plot(sim_propComplete[k,], xlab = "Iteration", ylab = "Proportion complete")
plot(sim_meanDensity[k,], xlab = "Iteration", ylab = "Mean density")

# Proportion of observed versus potential triangles
sim_hh_size <- HH_global %v% "hh_size"
simSampleSize <- table(sim_hh_size)/sort(unique(sim_hh_size))		# Number of HHs per HH size (sample sizes)
simCompleteTriangles <- choose(sort(unique(sim_hh_size)),3)
simPotentialTriangles <- simSampleSize*simCompleteTriangles
nr <- dim(simTriangles)[1]
simClustering <- simTriangles/matrix(rep(simPotentialTriangles, each = nr), nrow = nr)			# per HH size
simClustering_67 <- apply(simTriangles[,5:6],1,sum)/sum(simPotentialTriangles[5:6]) 		# HH size >=6
simClustering_567 <- apply(simTriangles[,4:6],1,sum)/sum(simPotentialTriangles[4:6]) 		# HH size >=5
if (choice == "weekend_contacts"){
	simClustering <- cbind(simClustering[,-c(1,4:6)], simClustering_567)
	}else{
	simClustering <- cbind(simClustering[,-c(1,5:6)], simClustering_67)
	}
simClustering <- cbind(simClustering, apply(simTriangles,1,sum)/sum(simPotentialTriangles))	# Add total to the last column


## Summary table: proportion complete and mean density
simDistr_propComplete <- t(apply(sim_propComplete, 1, quantile, probs = c(0.50, 0.025, 0.975)))
simDistr_meanDensity <- t(apply(sim_meanDensity, 1, quantile, probs = c(0.50, 0.025, 0.975)))
result <- cbind(HH_global_density.table$HHsize, HH_global_density.table$nrHH, propComplete
, simDistr_propComplete, density, simDistr_meanDensity)
round(result, 2)

# LaTeX table: proportion complete and mean density
nCol <- dim(result)[2]
colnames(result) <- c("HH size", "Nr. HHs", "Proportion complete", "Median", "Q 2.5%", "Q 97.5%", "Mean density", "Median", "Q 2.5%", "Q 97.5%")
latexTable <- xtable(result, align = c(rep("c", 2), "r", rep("c", nCol-2)), digits = c(rep(0, 3), rep(2, nCol-2)) 
, caption = paste("Proportion of complete networks and mean network density, stratified by HH size, for the observed and ", nSim," simulated networks.",sep=""))
print(latexTable, include.rownames = FALSE, file = paste("GOF_", name, "_table_density.txt", sep = ""))

## Summary figure: proportion complete and mean density
n <- length(HH_global_density.table$HHsize)-1
weight <- pmax(log(HH_global_density.table$nrHH[1:n]/sum(HH_global_density.table$nrHH[1:n])+1),0.1)	# weights for sample size
if (choice == "weekend_contacts"){
  xAxis <- c("2-3",HH_global_density.table$HHsize[2:(n-1)], "5-7", "total")
}else{
  xAxis <- c(HH_global_density.table$HHsize[1:(n-1)], "6-7", "total")
}

# Proportion complete
windows(record=T)
boxplot(t(sim_propComplete), names = xAxis, ylim = c(0,1),  xlab = "Household size", ylab = "Proportion complete networks", main = paste("Simulated networks n =", nSim, sep=" "))
points(propComplete, pch = 8, lwd = 1.8, cex = c(6*weight, 1.2), col = "blue")
savePlot(filename = paste("GOF_", name, "_propComplete.eps", sep = ""), type = "eps", restoreConsole=TRUE)
dev.off()
# Mean density
windows(record=T)
boxplot(t(sim_meanDensity), names = xAxis, ylim = c(0,1), xlab = "Household size", ylab = "Mean network density", main = paste("Simulated networks n =", nSim, sep=" "))
points(density, pch = 8, lwd = 1.8, cex = c(6*weight, 1.2), col = "blue")
savePlot(filename = paste("GOF_", name, "_meanDensity.eps", sep = ""), type = "eps", restoreConsole=TRUE)
dev.off()


## Summary table: clustering
if (choice == "weekend_contacts"){
	range <- c(3:5, NA)
	}else{
	range <- c(3:6, NA)
	}
simDistr_clustering <- t(apply(simClustering, 2, quantile, probs = c(0.50, 0.025, 0.975)))
result <- cbind(range, sampleSize, obsClustering, simDistr_clustering)
round(result, 2)

# LaTeX table: clustering
nCol <- dim(result)[2]
colnames(result) <- c("HH size", "Nr. HHs", "Clustering", "Median", "Q 2.5%", "Q 97.5%")
latexTable <- xtable(result, align = c(rep("c", 2), "r", rep("c", nCol-2)), digits = c(rep(0, 3), rep(2, nCol-2)) 
, caption = paste("Proportion of observed versus potential triangles, stratified by HH size, for the observed and ", nSim," simulated networks.",sep=""))
print(latexTable, include.rownames = FALSE, file = paste("GOF_", name, "_table_clustering.txt", sep = ""))

## Summary figure: clustering
n <- length(sampleSize)
weight <- pmax(log(sampleSize[-n]/sum(sampleSize[-n])+1),0.1)	# weights for sample size
if (choice == "weekend_contacts"){
	xAxis <- c(3, 4, "5-7", "total")
	}else{
	xAxis <- c(3, 4, 5, "6-7", "total")
	}
windows(record=T)
boxplot(simClustering, names = xAxis, ylim = c(0,1),  xlab = "Household size", ylab = "Observed vs. potential triangles", main = paste("Simulated networks n =", nSim, sep=" "))
points(obsClustering, pch = 8, lwd = 1.8, cex = c(6*weight, 1.2), col = "blue")
savePlot(filename = paste("GOF_", name, "_clustering.eps", sep = ""), type = "eps", restoreConsole=TRUE)
dev.off()



## Using the 'gof' function 	(problem: there seems to be an incompatibility between 'gof' and the use of offset terms -> coef)
############################

gof.model <- gof(model)
#gof.model <- gof(model, coef = NULL)	# uses vector of zero's as coefficients

#gof.model <- gof(model, coef = model$coef[3:length(model$coef)], GOF = ~ degree #+ espartners + distance + triadcensus + model
#, control = control.gof.ergm(nsim = 3, MCMC.burnin = interval, MCMC.interval = interval), verbose = TRUE, seed = 1515)

#gof.model <- gof(model ~ degree #+ espartners + distance + triadcensus + model
#, control = control.gof.formula(nsim = 3, MCMC.burnin = interval, MCMC.interval = interval), verbose = TRUE, seed = 1515)

summary(gof.model)
plot(gof.model)


###############################################
# SIMULATION WEEK NETWORKS FROM WEEKEND MODEL #
###############################################

## Load weekend model
#####################

setwd(paste(wd, "Eva/Results/ERGM/weekend_contacts/Final model", sep = ""))  

## Final weekend model
load("ERGM_role_agemixchildren_2star_triangle.RData")
rm(HH_global)

## Model coefficients
coef = model$coef


## Load week model
##################

setwd(paste(wd, "Eva/Results/ERGM/week_contacts/Final model", sep = ""))  

## Final week model
load("ERGM_role_smallHH_largeHH_agemixchildren_2star_triangle_triangleHH6+.RData")


## Simulate networks from fitted model
########################################

# Choose the number of networks to simulate
nSim <- 1000

# Assign name for output
name <- paste("sim_weekendmodel_weeknetwork_n_", nSim, sep = "")

# Choose the burnin and number of proposals between sampled statistics
interval <- 1e+6
burnin <- 1e+7 

# Set control options for simulation
control.choice.sim <- control.simulate.formula(MCMC.burnin = burnin, MCMC.interval = interval, MCMC.runtime.traceplot = FALSE)

# Simulate networks from weekend model based on characteristics of the week model (size, hh's,etc)  
# The end of one simulation is used as the start of the next simulation (sequential = TRUE)
# The first simulated Markov chain begins at the observed week network:
# Make sure HH_global is the week network!!

#HH_sim <- simulate(HH_global ~ edges + nodematch("hh_id") + nodemix("hh_role", base = c(3,6,1))+ nodecovstrat("age", "child")+ kstar(2)+ triangle, coef = coef, nsim = nSim, control = control.choice.sim, sequential = TRUE, verbose = TRUE, seed = 1515)


# Save and load simulated networks
# --------------------------------

setwd(paste(wd, "Eva/Results/ERGM/", sep = ""))  

#save(HH_sim, file = paste(name, ".RData", sep = ""))
#load(paste(name, ".RData", sep = ""))

class(HH_sim)
#print(HH_sim[[1]])

# Check whether constraint of between-HH mixing is satisfied
edges <- summary(HH_sim ~ edges)
HH_edges <- summary(HH_sim ~ nodematch("hh_id"))
sum(edges == HH_edges) == dim(edges)[1]



###############################################
# SIMULATION NETWORKS FROM WEEK/WEEKEND MODEL #
###############################################

## Load model
#############

## Final week model
setwd(paste(wd, "Eva/Results/ERGM/week_contacts/Final model", sep = ""))  
load("ERGM_role_smallHH_largeHH_agemixchildren_2star_triangle_triangleHH6+.RData")
rm(HH_global)
## Model coefficients
coef_week = model$coef

## Final weekend model
setwd(paste(wd, "Eva/Results/ERGM/weekend_contacts/Final model", sep = ""))  
load("ERGM_role_agemixchildren_2star_triangle.RData")
rm(HH_global)
## Model coefficients
coef_weekend = model$coef


## Load network
###############

setwd(paste(wd, "Eva/Results", sep = ""))
load("HH_network.RData")  # physical contacts only
print(HH_global)		# n = 1259
length(unique(HH_global %v% "hh_id"))		# n = 316 (all), 225 (week), 91 (weekend)


## Simulate networks from fitted model
########################################

# Choose the number of networks to simulate
nSim <- 1000

# Choose the burnin and number of proposals between sampled statistics
interval <- 1e+6
burnin <- 1e+8 #increased from 1e7, since the starting network is different from observed network used in the models

# Set control options for simulation
control.choice.sim <- control.simulate.formula(MCMC.burnin = burnin, MCMC.interval = interval, MCMC.runtime.traceplot = FALSE)

# Simulate networks from week/weekend model based on characteristics of the total model (size, hh's,etc)  
# The end of one simulation is used as the start of the next simulation (sequential = TRUE)
# The first simulated Markov chain begins at the observed week network:
# Make sure HH_global is the total network!!

## week
#HH_sim <- simulate(HH_global ~ edges + nodematch("hh_id") + nodemix("hh_role", base = c(3,6,1)) + nodecovstrat("age", "child")+ nodefactor("small_hh") + nodefactor("large_hh") + kstar(2)+ triangle+ trianglestrat("large_hh_6", diff = TRUE, keep = 2), coef = coef_week, nsim = nSim, control = control.choice.sim, sequential = TRUE, verbose = TRUE, seed = 1515)

## weekend
#HH_sim <- simulate(HH_global ~ edges + nodematch("hh_id") + nodemix("hh_role", base = c(3,6,1))+ nodecovstrat("age", "child")+ kstar(2)+ triangle, coef = coef_weekend, nsim = nSim, control = control.choice.sim, sequential = TRUE, verbose = TRUE, seed = 1515)


# Save and load simulated networks
# --------------------------------

setwd(paste(wd, "Eva/Results/ERGM/", sep = ""))  

# Assign name for output
name <- paste("sim_weekendmodel_totalnetwork_n_", nSim, sep = "")

#save(HH_sim, file = paste(name, ".RData", sep = ""))
#load(paste(name, ".RData", sep = ""))

class(HH_sim)
#print(HH_sim[[1]])

# Check whether constraint of between-HH mixing is satisfied
edges <- summary(HH_sim ~ edges)
HH_edges <- summary(HH_sim ~ nodematch("hh_id"))
sum(edges == HH_edges) == dim(edges)[1]

