# EPIDEMIC SIMULATION ON A STATIC CONTACT NETWORK
#
# APPLICATION TO THE TWO-LEVEL HOUSEHOLDS MODEL
#
# Based on:
#   Author: Nele Goeyvaerts
#   Last update: 25/06/2014
# 
# Last update: 27/05/2016
######################################################

rm(list = ls())
#memory.limit()


## Load required libraries
##############################
library(statnet)	
library(ergm.userterms)
library(scales)		# alpha color transparancy function
#library(animation)	# to make movies


## Set working directory (home / simlab)
###################################################
#wd <- "C:/Eva/CenStat/Projects/Nele - household networks/"
wd <- "D:/Eva/Uhasselt/CenStat/Projects/Nele - household networks/"


## Functions
###################################################

#setwd(paste(wd, "programs/R code/", sep = ""))
#source("density.R")


####################################################################
# Specify final model and load data: week network
####################################################################


## Week contacts
## -------------

setwd(paste(wd, "Eva/Results/ERGM/week_contacts/Final model/", sep = ""))  

# Simulated networks
load("sim_basis_complete_n_1000.RData")
HH_sim_week <- HH_sim[1:1000]
class(HH_sim_week)
rm(HH_sim)

# Density
#HH_sim_week_density <- sapply(HH_sim_week, density)
#save(HH_sim_week_density, file = "density_sim_basis_complete_n_1000.RData")
load("density_sim_basis_complete_n_1000.RData")


# Weekend contacts
# ----------------

setwd(paste(wd, "Eva/Results/ERGM/", sep = ""))  

# Simulated networks
load("sim_weekendmodel_weeknetwork_n_1000.RData")
HH_sim_weekend <- HH_sim[1:1000]
class(HH_sim_weekend)
rm(HH_sim)

# Density
#HH_sim_weekend_density <- sapply(HH_sim_weekend, function(x){a=density(x); print(a); return(a)})
#save(HH_sim_weekend_density, file = "density_sim_weekendmodel_weeknetwork_n_1000.RData")
load("density_sim_weekendmodel_weeknetwork_n_1000.RData")


####################################################################
# Specify final model and load data: total network
####################################################################


# ## Week contacts
# ## -------------
# 
# setwd(paste(wd, "Eva/Results/ERGM/", sep = ""))  
# 
# # Simulated networks
# load("sim_weekmodel_totalnetwork_n_1000.RData")
# HH_sim_week <- HH_sim[1:1000]
# class(HH_sim_week)
# rm(HH_sim)
# 
# # Density
# #HH_sim_week_density <- sapply(HH_sim_week, density)
# #save(HH_sim_week_density, file = "density_sim_weekmodel_totalnetwork_n_1000.RData")
# load("density_sim_weekmodel_totalnetwork_n_1000.RData")
# 
# 
# # Weekend contacts
# # ----------------
# 
# setwd(paste(wd, "Eva/Results/ERGM/", sep = ""))  
# 
# # Simulated networks
# load("sim_weekendmodel_totalnetwork_n_1000.RData")
# HH_sim_weekend <- HH_sim[1:1000]
# class(HH_sim_weekend)
# rm(HH_sim)
# 
# # Density
# #HH_sim_weekend_density <- sapply(HH_sim_weekend, function(x){a=density(x); print(a); return(a)})
# #save(HH_sim_weekend_density, file = "density_sim_weekendmodel_totalnetwork_n_1000.RData")
# load("density_sim_weekendmodel_totalnetwork_n_1000.RData")

## Checking both networks have the same size
## -----------------------------------------

#HH_sim_week[[1]]
#HH_sim_weekend[[1]]


#############################################################
# Load HH network with complete HH mixing                   #
#############################################################

setwd(paste(wd, "Eva/Results/", sep = ""))

## week network
load(file = "HH_complete_week.RData")
## total network
#load(file = "HH_complete.RData")

print(HH_complete)		# total edges original network = 2004 / week network: 1425


#######################################
# Choose setting and parameter values #
#######################################

HH_contact <- "randomMixing"
#HH_contact <- "ERGM"


## Household transmission
##------------------------------

# Equal transmission children/adults
hh_transm <- "constant"
# Age-dependent infectivity within hh
#hh_transm <- "ageDep"
# Independent households
#hh_transm <- "independent"

## Parameter values
# Within-household transmission probability per contact, per time step
if(hh_transm=="constant"|hh_transm=="independent"){
beta1 <- 0.05	# try beta1 = {0.0(2), 0.1, 0.2}
}else{
  beta1 <- c(0.2,0.1)
}

## Community transmission
##--------------------------

# Homogeneous mixing in the community
comm_transm <- "constant"
# Age-dependent mixing in the community (children <= 18 years versus adults > 18 years)
#comm_transm <- "ageDep"
# Constant foi from the community
#comm_transm <- "constant foi"

# Daily contact rates POLYMOD Belgium: physical contacts (smoothing Nele)

setwd(paste(wd, "data/contact rate matrices Nele/", sep = ""))
cij <- as.matrix(read.table("close.txt", header=F, sep=" "))
nr <- dim(cij)[1]
contactMatrix <- matrix(c(mean(cij[1:19, 1:19]), mean(cij[1:19, 20:nr]), mean(cij[20:nr, 1:19]), mean(cij[20:nr, 20:nr])), nrow = 2, ncol = 2)

# Parameter values
if (comm_transm == "ageDep"){
	# q is large because of different population sizes (household sample versus Belgian population)
	q2 <- 2.75e2			# try q2 = {1.5, 2.0, 2.5} * 10^2
	beta2 <- q2*contactMatrix
}else{ if(comm_transm == "constant"){
	q2 <- 0.000260
	beta2 <- matrix(q2,2,2)
	} else{beta2 = 0}
}
# "Mean" transmission rate
mu_beta2 <- mean(beta2)
mu_beta2


## Distribution infectious period: exp
##------------------------------------

infPeriodDistr <- "exp"

# Parameter values
gamma <- 0.22
	

## Number of initial infectives seeded
##--------------------------------------
nSeed <- 3


###########################################
# Discrete-time, chain binomial SIR model #
###########################################

setwd(paste(wd, "Eva/Programs/", sep = ""))

# Load epidemic model functions
source("epiChainBinModel_ES.R")


##############################
# Epidemic model: simulation #
##############################


## Number of simulations and seed
## ------------------------------
nSim <- 1000
seed <- 10102012
#seed <- 123
set.seed(seed)

if(hh_transm =="constant"){
  name <- paste("_beta1_", beta1, "_", comm_transm, "_q2_", q2, "_", infPeriodDistr
                , "_gamma_", gamma, "_nSeed_", nSeed, "_seed_", seed, sep="")
}
if(hh_transm =="independent"){
  name <- paste("_",hh_transm,"_beta1_", beta1, "_", infPeriodDistr
                , "_gamma_", gamma, "_seed_", seed, sep="")
}else{
  name <- paste("_",hh_transm,"_beta1_", beta1[1],"-",beta1[2], "_", comm_transm, "_q2_", q2, "_", infPeriodDistr
                , "_gamma_", gamma, "_nSeed_", nSeed, "_seed_", seed, sep="")  
}
## note that ERGM can't handle 1000 simulation in one: split it up in parts of 200


## Run epidemic simulations
## ------------------------

if (HH_contact == "ERGM"){  
  p_contact <- 1
  p_contact_weekend <- 1
}

if (HH_contact == "randomMixing"){
  HH_network <- HH_complete
  HH_network_weekend <- HH_complete
}

result <- list()

ptm <- proc.time()
for (i in 1:nSim){

print(c("Run:", i))

if (HH_contact == "ERGM"){  
  HH_network <- HH_sim_week[[i]]
  HH_network_weekend <- HH_sim_weekend[[i]]
}

if (HH_contact == "randomMixing"){	
	p_contact <- HH_sim_week_density[i]
  p_contact_weekend <- HH_sim_weekend_density[i]
  #p_contact <- 1
  #p_contact_weekend <- 1
}

# Constant recovery probability / Week - weekend distinction / constant hh tranmission
if (comm_transm != "constant foi" & hh_transm == "constant"){
result[[i]] <- epiChainBinModel1(HH_network = HH_network, beta1 = beta1, p_contact = p_contact, beta2 = beta2, gamma = gamma, nSeed = nSeed, HH_network_weekend = HH_network_weekend, p_contact_weekend = p_contact_weekend)
}

# Constant recovery probability / Week - weekend distinction / age-dependent hh transmission
if (comm_transm != "constant foi" & hh_transm == "ageDep"){
  result[[i]] <- epiChainBinModel11(HH_network = HH_network, beta1 = beta1, p_contact = p_contact, beta2 = beta2, gamma = gamma, nSeed = nSeed, HH_network_weekend = HH_network_weekend, p_contact_weekend = p_contact_weekend)
}

# Constant recovery probability / Week - weekend distinction / constant hh transmission / Constant community transmission
if (comm_transm == "constant foi" & hh_transm != "independent"){
result[[i]] <- epiChainBinModel2(HH_network = HH_network, beta1 = beta1, p_contact = p_contact, beta2 = beta2, gamma = gamma, nSeed = nSeed, HH_network_weekend = HH_network_weekend, p_contact_weekend = p_contact_weekend)
}

# Constant recovery probability / Week - weekend distinction / independent hh's/ constant hh transmission / No community transmission
if (hh_transm == "independent"){
  result[[i]] <- epiChainBinModel_ind(HH_network = HH_network, beta1 = beta1, p_contact = p_contact, gamma = gamma, HH_network_weekend = HH_network_weekend, p_contact_weekend = p_contact_weekend)
}
# Constant recovery probability / No distinction
#result[[i]] <- epiChainBinModel1(HH_network = HH_network, beta1 = beta1, p_contact = p_contact, beta2 = beta2, gamma = gamma, nSeed = nSeed)
}
proc.time()-ptm

# Save result
setwd(paste(wd, "Eva/Results/Epidemic simulation/", sep = ""))
save(result, file = paste("list_sim_", HH_contact, "_nSim_", nSim, name, ".RData", sep=""))

# # ERGM: combine 5 simulation sets in 1
# setwd(paste(wd, "Eva/Results/Epidemic simulation", sep = ""))
# load(file = paste("list_sim_", HH_contact, "_nSim_", nSim, name, "_1.RData", sep=""))
# r1 = result
# rm(result)
# load(file = paste("list_sim_", HH_contact, "_nSim_", nSim, name, "_2.RData", sep=""))
# r2 = result
# rm(result)
# load(file = paste("list_sim_", HH_contact, "_nSim_", nSim, name, "_3.RData", sep=""))
# r3 = result
# rm(result)
# load(file = paste("list_sim_", HH_contact, "_nSim_", nSim, name, "_4.RData", sep=""))
# r4= result
# rm(result)
# load(file = paste("list_sim_", HH_contact, "_nSim_", nSim, name, "_5.RData", sep=""))
# r5 = result
# rm(result)
# load(file = paste("list_sim_", HH_contact, "_nSim_", nSim, name, "_6.RData", sep=""))
# r6 = result
# rm(result)
# load(file = paste("list_sim_", HH_contact, "_nSim_", nSim, name, "_7.RData", sep=""))
# r7 = result
# rm(result)
# load(file = paste("list_sim_", HH_contact, "_nSim_", nSim, name, "_8.RData", sep=""))
# r8 = result
# rm(result)
# load(file = paste("list_sim_", HH_contact, "_nSim_", nSim, name, "_9.RData", sep=""))
# r9= result
# rm(result)
# load(file = paste("list_sim_", HH_contact, "_nSim_", nSim, name, "_10.RData", sep=""))
# r10 = result
# rm(result)
# result = c(r1,r2,r3,r4,r5,r6,r7,r8,r9,r10)
# save(result, file = paste("list_sim_", HH_contact, "_nSim_1000", name, ".RData", sep=""))


##############################
# Summary Statistics         #
##############################


## Load epidemic model summary function and epidemic model plotting functions
## --------------------------------------------------------------------------

setwd(paste(wd, "Eva/Programs/", sep = ""))
source("epiSummary_ES.R")
setwd(paste(wd, "programs/R code/", sep = ""))
source("epiModelPlots.R")


## Load simulations
## ----------------

setwd(paste(wd, "Eva/Results/Epidemic simulation/Week-weekend/Setting 16", sep = ""))
load(file = paste("list_sim_", HH_contact, "_nSim_", nSim, name, ".RData", sep=""))

# ## Excluding FOI calculations (in case of memory problems)
# result.new = list()
# for (i in 1:length(result)){
#  result.new[[i]] = list(timeSteps = result[[i]]$timeSteps, infectedMat = result[[i]]$infectedMat, incidenceMat = result[[i]]$incidenceMat, HH_network = result[[i]]$HH_network, weekend = result[[i]]$weekend)
# }
# result = result.new
# result[[1]]
# save(result, file = paste("list_sim_", HH_contact, "_nSim_1000", name, "_no_FOI.RData", sep=""))


## Initiate variables
## ------------------

duration <- rep(NA, nSim)
weekendFraction <- rep(NA, nSim)
finalSize <- rep(NA, nSim)
finalFraction <- rep(NA, nSim)
hhFinalSize <- rep(NA, nSim)
hhFinalFraction <- rep(NA, nSim)
extinction <- rep(NA, nSim)
infPeriod <- rep(NA, nSim)
CPIchild <- rep(NA, nSim) 
CPIadult <- rep(NA, nSim) 
hhPropInfected <- rep(NA, nSim)
hhDuration <- rep(NA, nSim)

maxTime <- 500
incidence <- matrix(0, nrow = nSim, ncol = maxTime)
incidenceChild <- matrix(0, nrow = nSim, ncol = maxTime)
incidenceFather <- matrix(0, nrow = nSim, ncol = maxTime)
incidenceMother <- matrix(0, nrow = nSim, ncol = maxTime)
hhIncidence <- matrix(0, nrow = nSim, ncol = maxTime)
if (hh_transm == "ageDep"){
  hhfoi_child <- matrix(NA, nrow = nSim, ncol = maxTime-1)
  hhfoi_adult <- matrix(NA, nrow = nSim, ncol = maxTime-1)
}else{ 
  hhfoi <- matrix(NA, nrow = nSim, ncol = maxTime-1)
}
comfoi_child <- matrix(NA, nrow = nSim, ncol = maxTime)
comfoi_adult <- matrix(NA, nrow = nSim, ncol = maxTime)
cases <- matrix(0, nrow = nSim, ncol = maxTime)

if (hh_transm=="independent"){
  range <- c("<=3","4","5",">=6")
}else{range <- c("2","3","4","5",">=6")}

hhFinalFraction_hhsize <- matrix(NA, nrow = nSim, ncol = length(range))
hhPropInfected_hhsize <- matrix(NA, nrow = nSim, ncol = length(range))
hhSecInfected_hhsize <- matrix(NA, nrow = nSim, ncol = length(range))
hhInfectedTable_hhsize <- array(NA, c(length(range), length(range)+2,nSim))
hhDuration_hhsize <- matrix(NA, nrow = nSim, ncol = length(range))
hhIncidence_hhsize <- array(0, c(length(range), maxTime, nSim))
hhPropInfected_role <- matrix(NA, nrow = nSim, ncol = 3)
hhDuration_role <- matrix(NA, nrow = nSim, ncol = 3)
if (hh_transm == "ageDep"){
  hhfoi_child_hhsize <- array(NA, c(length(range), maxTime, nSim))
  hhfoi_adult_hhsize <- array(NA, c(length(range), maxTime, nSim))
}else{
  hhfoi_hhsize <- array(NA, c(length(range), maxTime, nSim))
}
comfoi_child_hhsize <- array(NA, c(length(range), maxTime, nSim))
comfoi_adult_hhsize <- array(NA, c(length(range), maxTime, nSim))

hh_id <- HH_complete %v% "hh_id"
hh_id_unique <- unique(hh_id)
hhIndexCase <- matrix(NA, nrow = nSim, ncol = length(hh_id_unique))
hhIndexCaseAll <- matrix(NA, nrow = nSim, ncol = length(hh_id_unique))
hhLastCase <- matrix(NA, nrow = nSim, ncol = length(hh_id_unique))


for (i in 1:nSim){
  
print(c("Run:", i))
  
# Model summary
if (hh_transm == "constant"){
  statistics <- epiSummary(result[[i]], display = FALSE)
}
if(hh_transm == "ageDep"){
  statistics <- epiSummary11(result[[i]], display = FALSE)
}
if(hh_transm == "independent"){
  statistics <- epiSummary_ind(result[[i]], display = FALSE)
}

# Duration of epidemic
if(hh_transm != "independent"){
  duration[i] <- result[[i]]$timeSteps

  # Check week/weekend distribution
  weekendFraction[i] <- sum(result[[i]]$weekend)/duration[i]
}

# Final size/fraction: individuals and households
finalSize[i] <- statistics$finalSize
finalFraction[i] <- statistics$finalFraction
hhFinalSize[i] <- statistics$hhFinalSize
hhFinalFraction[i] <- statistics$hhFinalFraction

if(hh_transm != "independent"){
  # Final fraction households per household size category
  hhFinalFraction_hhsize[i, ] <- statistics$hhFinalFractionHHsize

  # Incidence per time step
  incidence[i, 1:duration[i]] <- statistics$incidence
  incidenceChild[i, 1:duration[i]] <- statistics$incidenceChild
  incidenceFather[i, 1:duration[i]] <- statistics$incidenceFather
  incidenceMother[i, 1:duration[i]] <- statistics$incidenceMother
  hhIncidence[i, 1:duration[i]] <- statistics$hhIncidence

  # Number of cases per time step
  cases[i, 1:duration[i]] <- statistics$cases

  # Incidence per household size per time step
  hhIncidence_hhsize[,1:duration[i],i] <- statistics$hhIncidence_hhsize

  # Foi per time step
  if (hh_transm == "constant"){
    hhfoi[i, 1:(duration[i]-1)] <- statistics$hhfoiMean
  }else{
    hhfoi_child[i, 1:(duration[i]-1)] <- statistics$hhfoiMean_child
    hhfoi_adult[i, 1:(duration[i]-1)] <- statistics$hhfoiMean_adult
  }
  comfoi_child[i, 1:(duration[i]-1)] <- statistics$comfoiMean_child
  comfoi_adult[i, 1:(duration[i]-1)] <- statistics$comfoiMean_adult

  # Foi per household size per time step
  if (hh_transm == "constant"){
    hhfoi_hhsize[, 1:(duration[i]-1),i] <- statistics$hhfoi_hhsize
  }else{
    hhfoi_child_hhsize[, 1:(duration[i]-1),i] <- statistics$hhfoi_child_hhsize
    hhfoi_adult_hhsize[, 1:(duration[i]-1),i] <- statistics$hhfoi_adult_hhsize
  }
  comfoi_child_hhsize[, 1:(duration[i]-1),i] <- statistics$comfoi_child_hhsize
  comfoi_adult_hhsize[, 1:(duration[i]-1),i] <- statistics$comfoi_adult_hhsize

  # Extinction
  extinction[i] <- statistics$extinction
}

# Mean duration of infectiousness
infPeriod[i] <- mean(statistics$infPeriod, na.rm = TRUE)

if(hh_transm != "independent"){
  # Community probability of infection
  CPIchild[i] <- statistics$CPIchild
  CPIadult[i] <- statistics$CPIadult
}

# Mean proportion infected per household size
hhPropInfected_hhsize[i, ] <- statistics$hhPropInfectedMean

# Mean proportion secundary cases per household size
hhSecInfected_hhsize[i, ] <- statistics$hhSecInfectedMean

if(hh_transm != "independent"){
  # Distribution number infected per household size
  hhInfectedTable_hhsize[, ,i] <- statistics$hhInfectedTable
}

# Mean time from first onset to the last case per household size
hhDuration_hhsize[i, ] <- statistics$hhDurationMean

if(hh_transm == "independent"){
# Mean proportion infected per role index case
hhPropInfected_role[i, ] <- statistics$hhPropInfected_role

# Mean time from first onset to the last case per household size
hhDuration_role[i, ] <- statistics$hhDuration_role
}

# Mean proportion infected (overall)
hhPropInfected[i] <- mean(statistics$hhPropInfected, na.rm = TRUE)

# Mean time from first onset to the last case (overall)
hhDuration[i] <- mean(statistics$hhDuration, na.rm = TRUE)

if(hh_transm != "independent"){
  # Role of index case 
  hhIndexCaseAll[i, ] <- statistics$hhIndexCaseAll
  # Role of last case 
  hhLastCase[i, ] <- statistics$hhLastCase
}

# Role of index case 
hhIndexCase[i, ] <- statistics$hhIndexCase

}

## Save simulation results 
## -----------------------

if (hh_transm == "ageDep"){
  output <- list(nSim = nSim, duration = duration, weekendFraction = weekendFraction, finalSize = finalSize
                 , finalFraction = finalFraction, incidence = incidence, incidenceChild = incidenceChild, incidenceFather = incidenceFather
                 , incidenceMother = incidenceMother, extinction = extinction, cases = cases, infPeriod = infPeriod
                 , CPIchild = CPIchild, CPIadult = CPIadult, hhFinalSize = hhFinalSize
                 , hhFinalFraction = hhFinalFraction, hhFinalFraction_hhsize = hhFinalFraction_hhsize, hhIncidence = hhIncidence, hhIncidence_hhsize = hhIncidence_hhsize
                 , hhPropInfected_hhsize = hhPropInfected_hhsize, hhSecInfected_hhsize = hhSecInfected_hhsize, hhDuration_hhsize = hhDuration_hhsize, hhPropInfected = hhPropInfected
                 , hhDuration = hhDuration, hhIndexCase = hhIndexCase, hhIndexCaseAll = hhIndexCaseAll, hhLastCase = hhLastCase, hhInfectedTable_hhsize = hhInfectedTable_hhsize
                 , hhfoi_child = hhfoi_child, hhfoi_adult = hhfoi_adult, comfoi_child = comfoi_child, comfoi_adult = comfoi_adult
                 , hhfoi_child_hhsize = hhfoi_child_hhsize, hhfoi_adult_hhsize = hhfoi_adult_hhsize, comfoi_child_hhsize = comfoi_child_hhsize, comfoi_adult_hhsize = comfoi_adult_hhsize
  )
}else{
  if (hh_transm == "independent"){
    output <- list(nSim = nSim, finalSize = finalSize, finalFraction = finalFraction
                   , infPeriod = infPeriod, hhFinalSize = hhFinalSize, hhFinalFraction = hhFinalFraction
                   , hhFinalFraction_hhsize = hhFinalFraction_hhsize, hhPropInfected_hhsize = hhPropInfected_hhsize, hhSecInfected_hhsize = hhSecInfected_hhsize, hhDuration_hhsize = hhDuration_hhsize 
                   , hhPropInfected = hhPropInfected, hhDuration = hhDuration, hhIndexCase = hhIndexCase, hhDuration_role = hhDuration_role, hhPropInfected_role = hhPropInfected_role
    )   
  }else{
    output <- list(nSim = nSim, duration = duration, weekendFraction = weekendFraction, finalSize = finalSize
                 , finalFraction = finalFraction, incidence = incidence, incidenceChild = incidenceChild, incidenceFather = incidenceFather
                 , incidenceMother = incidenceMother, extinction = extinction, cases = cases, infPeriod = infPeriod
                 , CPIchild = CPIchild, CPIadult = CPIadult, hhFinalSize = hhFinalSize
                 , hhFinalFraction = hhFinalFraction, hhFinalFraction_hhsize = hhFinalFraction_hhsize, hhIncidence = hhIncidence, hhIncidence_hhsize = hhIncidence_hhsize
                 , hhPropInfected_hhsize = hhPropInfected_hhsize, hhSecInfected_hhsize = hhSecInfected_hhsize, hhDuration_hhsize = hhDuration_hhsize, hhPropInfected = hhPropInfected
                 , hhDuration = hhDuration, hhIndexCase = hhIndexCase, hhIndexCaseAll = hhIndexCaseAll, hhLastCase = hhLastCase, hhInfectedTable_hhsize = hhInfectedTable_hhsize
                 , hhfoi = hhfoi, comfoi_child = comfoi_child, comfoi_adult = comfoi_adult
                 , hhfoi_hhsize = hhfoi_hhsize, comfoi_child_hhsize = comfoi_child_hhsize, comfoi_adult_hhsize = comfoi_adult_hhsize
    )
 }
}

setwd(paste(wd, "Eva/Results/Epidemic simulation/", sep = ""))
save(output, file = paste("sim_", HH_contact, "_nSim_", nSim, name, ".RData", sep=""))

# Clear memory
rm(list = c("output", "nSim", "duration", "weekendFraction", "finalSize", "finalFraction", "incidence", "incidenceChild", "incidenceFather"
	, "incidenceMother", "extinction", "cases", "infPeriod", "CPIchild", "CPIadult", "hhFinalSize", "hhFinalFraction" , "hhIncidence", "hhPropInfected_hhsize", "hhSecInfected_hhsize"
	, "hhDuration_hhsize", "hhPropInfected", "hhDuration", "hhIndexCase", "hhIndexCaseAll", "hhLastCase", "hhInfectedTable_hhsize"
  , "hhfoi", "comfoi_child", "comfoi_adult", "hhfoi_hhsize", "comfoi_child_hhsize", "comfoi_adult_hhsize"))


######################################
## Comparing two (three) models     ##
######################################

setwd(paste(wd, "Eva/Results/", sep = ""))
load(file = "HH_complete_week.RData")
#load(file = "HH_complete.RData")


## Load epidemic model summary function and epidemic model plotting functions
## --------------------------------------------------------------------------

setwd(paste(wd, "programs/R code/", sep = ""))
source("epiSummary.R")
source("epiModelPlots.R")


## Load simulation results
## -----------------------

#hh_transm <- "ageDep"
hh_transm <- "constant"
#hh_transm <- "independent"

comm_transm <- "ageDep"
#comm_transm <- "constant"

setwd(paste(wd, "Eva/Results/Epidemic simulation/Week-weekend/Setting 5/", sep = ""))
nSim <- 1000
seed <- 10102012

beta1 <- 0.05  # try beta1 = {0.0(2), 0.1, 0.2}
#beta1 <- c(0.4,0.05)

q2 <- 2.75e2			# try q2 = {1.5, 2.0, 2.5} * 10^2
#q2 <- 0.000260

infPeriodDistr <- "exp"
gamma <- 0.22
nSeed <- 3
HH_network = HH_complete

if(hh_transm =="constant"){
  name <- paste("_beta1_", beta1, "_", comm_transm, "_q2_", q2, "_", infPeriodDistr
                , "_gamma_", gamma, "_nSeed_", nSeed, "_seed_", seed, sep="")
}else{
if(hh_transm =="independent"){
  name <- paste("_",hh_transm,"_beta1_", beta1, "_", infPeriodDistr
                , "_gamma_", gamma, "_seed_", seed, sep="")
}else{
  name <- paste("_",hh_transm,"_beta1_", beta1[1],"-",beta1[2], "_", comm_transm, "_q2_", q2, "_", infPeriodDistr
                , "_gamma_", gamma, "_nSeed_", nSeed, "_seed_", seed, sep="")  
}}

## Random mixing 
name1 <- "Random mixing"
abbrev1 <- "Random"
load(paste("sim_", "randomMixing", "_nSim_", nSim, name, ".RData", sep=""))

if(hh_transm =="ageDep"){
  model1 <- list(nSim = output$nSim, duration = output$duration, weekendFraction = output$weekendFraction
                 , finalSize = output$finalSize, finalFraction = output$finalFraction, incidence = output$incidence
                 , incidenceChild = output$incidenceChild, incidenceFather = output$incidenceFather
                 , incidenceMother = output$incidenceMother, extinction = output$extinction, cases = output$cases, infPeriod = output$infPeriod
                 , CPIchild = output$CPIchild, CPIadult = output$CPIadult, hhFinalSize = output$hhFinalSize, hhFinalFraction = output$hhFinalFraction, hhFinalFraction_hhsize = output$hhFinalFraction_hhsize
                 , hhIncidence = output$hhIncidence, hhIncidence_hhsize = output$hhIncidence_hhsize, hhPropInfected_hhsize = output$hhPropInfected_hhsize, hhSecInfected_hhsize = output$hhSecInfected_hhsize
                 , hhDuration_hhsize = output$hhDuration_hhsize
                 , hhPropInfected = output$hhPropInfected, hhDuration = output$hhDuration, hhIndexCase = output$hhIndexCase, hhIndexCaseAll = output$hhIndexCaseAll
                 , hhLastCase = output$hhLastCase, hhInfectedTable_hhsize = output$hhInfectedTable_hhsize
                 , hhfoi_child = output$hhfoi_child, hhfoi_adult = output$hhfoi_adult, comfoi_child = output$comfoi_child, comfoi_adult = output$comfoi_adult
                 , hhfoi_child_hhsize = output$hhfoi_child_hhsize, hhfoi_adult_hhsize = output$hhfoi_adult_hhsize, comfoi_child_hhsize = output$comfoi_child_hhsize, comfoi_adult_hhsize = output$comfoi_adult_hhsize
  )  
}else{
  if(hh_transm=="independent"){
    model1 <- list(nSim = output$nSim, finalSize = output$finalSize, finalFraction = output$finalFraction
                   , infPeriod = output$infPeriod, hhFinalSize = output$hhFinalSize, hhFinalFraction = output$hhFinalFraction, hhFinalFraction_hhsize = output$hhFinalFraction_hhsize
                   , hhPropInfected_hhsize = output$hhPropInfected_hhsize, hhSecInfected_hhsize = output$hhSecInfected_hhsize, hhDuration_hhsize = output$hhDuration_hhsize
                   , hhPropInfected = output$hhPropInfected, hhDuration = output$hhDuration, hhIndexCase = output$hhIndexCase, hhDuration_role = output$hhDuration_role, hhPropInfected_role = output$hhPropInfected_role
    ) 
  }else{model1 <- list(nSim = output$nSim, duration = output$duration, weekendFraction = output$weekendFraction
                 , finalSize = output$finalSize, finalFraction = output$finalFraction, incidence = output$incidence
                 , incidenceChild = output$incidenceChild, incidenceFather = output$incidenceFather
                 , incidenceMother = output$incidenceMother, extinction = output$extinction, cases = output$cases, infPeriod = output$infPeriod
                 , CPIchild = output$CPIchild, CPIadult = output$CPIadult, hhFinalSize = output$hhFinalSize, hhFinalFraction = output$hhFinalFraction, hhFinalFraction_hhsize = output$hhFinalFraction_hhsize
                 , hhIncidence = output$hhIncidence, hhIncidence_hhsize = output$hhIncidence_hhsize, hhPropInfected_hhsize = output$hhPropInfected_hhsize, hhSecInfected_hhsize = output$hhSecInfected_hhsize
                 , hhDuration_hhsize = output$hhDuration_hhsize
                 , hhPropInfected = output$hhPropInfected, hhDuration = output$hhDuration, hhIndexCase = output$hhIndexCase, hhIndexCaseAll = output$hhIndexCaseAll
                 , hhLastCase = output$hhLastCase, hhInfectedTable_hhsize = output$hhInfectedTable_hhsize
                 , hhfoi = output$hhfoi, comfoi_child = output$comfoi_child, comfoi_adult = output$comfoi_adult
                 , hhfoi_hhsize = output$hhfoi_hhsize, comfoi_child_hhsize = output$comfoi_child_hhsize, comfoi_adult_hhsize = output$comfoi_adult_hhsize
  )
  }
}
# Clear memory
rm("output")

## ERGM
name2 <- "ERGM"
abbrev2 <- "ERGM"
load(paste("sim_", "ERGM", "_nSim_", nSim, name, ".RData", sep=""))

if(hh_transm =="ageDep"){
  model2 <- list(nSim = output$nSim, duration = output$duration, weekendFraction = output$weekendFraction
                 , finalSize = output$finalSize, finalFraction = output$finalFraction, incidence = output$incidence
                 , incidenceChild = output$incidenceChild, incidenceFather = output$incidenceFather
                 , incidenceMother = output$incidenceMother, extinction = output$extinction, cases = output$cases, infPeriod = output$infPeriod
                 , CPIchild = output$CPIchild, CPIadult = output$CPIadult, hhFinalSize = output$hhFinalSize, hhFinalFraction = output$hhFinalFraction, hhFinalFraction_hhsize = output$hhFinalFraction_hhsize
                 , hhIncidence = output$hhIncidence, hhIncidence_hhsize = output$hhIncidence_hhsize, hhPropInfected_hhsize = output$hhPropInfected_hhsize, hhSecInfected_hhsize = output$hhSecInfected_hhsize
                 , hhDuration_hhsize = output$hhDuration_hhsize
                 , hhPropInfected = output$hhPropInfected, hhDuration = output$hhDuration, hhIndexCase = output$hhIndexCase, hhIndexCaseAll = output$hhIndexCaseAll
                 , hhLastCase = output$hhLastCase, hhInfectedTable_hhsize = output$hhInfectedTable_hhsize
                 , hhfoi_child = output$hhfoi_child, hhfoi_adult = output$hhfoi_adult, comfoi_child = output$comfoi_child, comfoi_adult = output$comfoi_adult
                 , hhfoi_child_hhsize = output$hhfoi_child_hhsize, hhfoi_adult_hhsize = output$hhfoi_adult_hhsize, comfoi_child_hhsize = output$comfoi_child_hhsize, comfoi_adult_hhsize = output$comfoi_adult_hhsize
  )  
}else{
  if(hh_transm=="independent"){
    model2 <- list(nSim = output$nSim, finalSize = output$finalSize, finalFraction = output$finalFraction
                   , infPeriod = output$infPeriod, hhFinalSize = output$hhFinalSize, hhFinalFraction = output$hhFinalFraction, hhFinalFraction_hhsize = output$hhFinalFraction_hhsize
                   , hhPropInfected_hhsize = output$hhPropInfected_hhsize, hhSecInfected_hhsize = output$hhSecInfected_hhsize, hhDuration_hhsize = output$hhDuration_hhsize
                   , hhPropInfected = output$hhPropInfected, hhDuration = output$hhDuration, hhIndexCase = output$hhIndexCase, hhDuration_role = output$hhDuration_role, hhPropInfected_role = output$hhPropInfected_role
    ) 
  }else{model2 <- list(nSim = output$nSim, duration = output$duration, weekendFraction = output$weekendFraction
                       , finalSize = output$finalSize, finalFraction = output$finalFraction, incidence = output$incidence
                       , incidenceChild = output$incidenceChild, incidenceFather = output$incidenceFather
                       , incidenceMother = output$incidenceMother, extinction = output$extinction, cases = output$cases, infPeriod = output$infPeriod
                       , CPIchild = output$CPIchild, CPIadult = output$CPIadult, hhFinalSize = output$hhFinalSize, hhFinalFraction = output$hhFinalFraction, hhFinalFraction_hhsize = output$hhFinalFraction_hhsize
                       , hhIncidence = output$hhIncidence, hhIncidence_hhsize = output$hhIncidence_hhsize, hhPropInfected_hhsize = output$hhPropInfected_hhsize, hhSecInfected_hhsize = output$hhSecInfected_hhsize
                       , hhDuration_hhsize = output$hhDuration_hhsize
                       , hhPropInfected = output$hhPropInfected, hhDuration = output$hhDuration, hhIndexCase = output$hhIndexCase, hhIndexCaseAll = output$hhIndexCaseAll
                       , hhLastCase = output$hhLastCase, hhInfectedTable_hhsize = output$hhInfectedTable_hhsize
                       , hhfoi = output$hhfoi, comfoi_child = output$comfoi_child, comfoi_adult = output$comfoi_adult
                       , hhfoi_hhsize = output$hhfoi_hhsize, comfoi_child_hhsize = output$comfoi_child_hhsize, comfoi_adult_hhsize = output$comfoi_adult_hhsize
  )
  }
}
# Clear memory
rm("output")

## Random mixing - no correction
name3 <- "Random mixing"
abbrev3 <- "Random - no correction"
load(paste("sim_", "randomMixing_delta_1", "_nSim_", nSim, name, ".RData", sep=""))

# model3 <- list(nSim = output$nSim, duration = output$duration, weekendFraction = output$weekendFraction
#                , finalSize = output$finalSize, finalFraction = output$finalFraction, incidence = output$incidence
#                , incidenceChild = output$incidenceChild, incidenceFather = output$incidenceFather
#                , incidenceMother = output$incidenceMother, extinction = output$extinction, infPeriod = output$infPeriod
#                , CPIchild = output$CPIchild, CPIadult = output$CPIadult, hhFinalSize = output$hhFinalSize, hhFinalFraction = output$hhFinalFraction
#                , hhIncidence = output$hhIncidence, hhIncidence_hhsize = output$hhIncidence_hhsize, hhPropInfected_hhsize = output$hhPropInfected_hhsize, hhSecInfected_hhsize = output$hhSecInfected_hhsize
#                , hhDuration_hhsize = output$hhDuration_hhsize
#                , hhPropInfected = output$hhPropInfected, hhDuration = output$hhDuration, hhIndexCase = output$hhIndexCase, hhIndexCaseAll = output$hhIndexCaseAll
#                , hhLastCase = output$hhLastCase, hhInfectedTable_hhsize = output$hhInfectedTable_hhsize
#                , hhfoi = output$hhfoi, comfoi_child = output$comfoi_child, comfoi_adult = output$comfoi_adult
#                , hhfoi_hhsize = output$hhfoi_hhsize, comfoi_child_hhsize = output$comfoi_child_hhsize, comfoi_adult_hhsize = output$comfoi_adult_hhsize
#                 )
# # Clear memory
# rm("output")

# Merge two lists!
# model <- mapply(c, model1, model2, SIMPLIFY=FALSE)
# model <- mapply(c, model1, model2, model3, SIMPLIFY=FALSE)


## Graphical display: compare two models
## -------------------------------------

sel1 = model1$extinction == FALSE
sel2 = model2$extinction == FALSE
#sel1 = rep(T,1000) 
#sel2 = rep(T,1000)

# Probability of extinction
print("Probability of extinction")
sum(model1$extinction)/model1$nSim
sum(model2$extinction)/model2$nSim
ext = matrix(c(sum(model1$extinction),model1$nSim-sum(model1$extinction),sum(model2$extinction),model2$nSim-sum(model2$extinction)),2,2)
fisher.test(ext)

# Fraction of weekend days sampled
summary(model1$weekendFraction)
summary(model2$weekendFraction)

# Duration of epidemic
windows(record=T,width=11, height=5)
par(mfrow= c(1,2))
hist(model1$duration, xlab = "Duration epidemic", main = name1, breaks=20)
hist(model2$duration, xlab = "Duration epidemic", main = name2, breaks=20)
savePlot(filename = paste("duration_hist", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off()
## exclusion extinctions
duration1 <- model1$duration[sel1]
duration2 <- model2$duration[sel2]
windows(record=T)
boxplot(duration1, duration2, names = c(name1, name2), ylab = "Duration epidemic", boxwex = 0.5, notch = TRUE)
savePlot(filename = paste("duration_boxplot", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off()

# Final size/fraction: individuals and households
hh_id <- HH_network %v% "hh_id"
nr_hh <- length(unique(hh_id))
# Histograms
#par(mfrow= c(2,2))
windows(record=T,width=11, height=5)
par(mfrow= c(1,2))
hist(model1$finalSize, xlab = "Final size (individuals)", main = name1, breaks = 20, cex.main = 1)	# font.main = 1 (normal font)
hist(model2$finalSize, xlab = "Final size (individuals)", main = name2, breaks = 20, cex.main = 1)
savePlot(filename = paste("finalSizeTotal_hist", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off() 
windows(record=T,width=11, height=5)
par(mfrow= c(1,2))
hist(model1$hhFinalSize, xlab = "Final size (households)", main = name1, breaks = seq(0, nr_hh+10, 10), cex.main = 1)
hist(model2$hhFinalSize, xlab = "Final size (households)", main = name2, breaks = seq(0, nr_hh+10, 10), cex.main = 1)
savePlot(filename = paste("finalSizeHH_hist", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off() 
windows(record=T,width=11, height=5)
par(mfrow=c(2,2))
hist(model1$finalFraction, xlab = "Proportion individuals affected", main = name1, breaks = seq(0, 1, 0.05), cex.main = 1)
hist(model2$finalFraction, xlab = "Proportion individuals affected", main = name2, breaks = seq(0, 1, 0.05), cex.main = 1)
hist(model1$hhFinalFraction, xlab = "Proportion households affected", main = name1, breaks = seq(0, 1, 0.05), cex.main = 1)
hist(model2$hhFinalFraction, xlab = "Proportion households affected", main = name2, breaks = seq(0, 1, 0.05), cex.main = 1)
savePlot(filename = paste("finalFraction_hist", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off()
# Only epidemics
finalSize1 <- model1$finalSize[sel1]
finalSize2 <- model2$finalSize[sel2]
hhFinalSize1 <- model1$hhFinalSize[sel1]
hhFinalSize2 <- model2$hhFinalSize[sel2]
finalFraction1 <- model1$finalFraction[sel1]
finalFraction2 <- model2$finalFraction[sel2]
hhFinalFraction1 <- model1$hhFinalFraction[sel1]
hhFinalFraction2 <- model2$hhFinalFraction[sel2]
# Boxplots 
windows(record=T,width=11, height=5)
par(mfrow= c(1,2))
boxplot(finalSize1, finalSize2, names = c(abbrev1, abbrev2), ylab = "Final size (individuals)", boxwex = 0.5, notch = TRUE)
boxplot(hhFinalSize1, hhFinalSize2, names = c(abbrev1, abbrev2), ylab = "Final size (households)", boxwex = 0.5, notch = TRUE)
savePlot(filename = paste("finalSize_boxplot", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off() 
windows(record=T,width=11, height=5)
par(mfrow= c(1,2))
llim <- min(c(finalFraction1, finalFraction2,hhFinalFraction1, hhFinalFraction2))
ulim <- max(c(finalFraction1, finalFraction2,hhFinalFraction1, hhFinalFraction2))
boxplot(finalFraction1, finalFraction2, ylim = c(llim, ulim), names = c(abbrev1, abbrev2), ylab = "Proportion individuals affected", boxwex = 0.5, notch = TRUE)
boxplot(hhFinalFraction1, hhFinalFraction2, ylim = c(llim, ulim), names = c(abbrev1, abbrev2), ylab = "Proportion households affected", boxwex = 0.5, notch = TRUE)
savePlot(filename = paste("finalFraction_boxplot", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off()
# Quantile plots 
windows(record=T,width=11, height=5)
par(mfrow= c(1,2))
qqplot(finalSize1, finalSize2, xlab=abbrev1, ylab=abbrev2, main = "Final size (individuals)"); abline(0,1)
qqplot(hhFinalSize1, hhFinalSize2, xlab=abbrev1, ylab=abbrev2, main = "Final size (households)"); abline(0,1)
savePlot(filename = paste("finalSize_qqplot", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off() 
windows(record=T,width=11, height=5)
par(mfrow= c(1,2))
qqplot(finalFraction1, finalFraction2, xlab=abbrev1, ylab=abbrev2, main = "Proportion individuals affected"); abline(0,1)
qqplot(hhFinalFraction1, hhFinalFraction2, xlab=abbrev1, ylab=abbrev2, main = "Proportion households affected"); abline(0,1)
savePlot(filename = paste("finalFraction_qqplot", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off()
# Descriptive statistics
summary(finalSize1)
summary(finalSize2)
summary(hhFinalSize1)
summary(hhFinalSize2)
summary(finalFraction1); quantile(finalFraction1,c(0.025,0.975))
summary(finalFraction2); quantile(finalFraction2,c(0.025,0.975))
summary(hhFinalFraction1); quantile(hhFinalFraction1,c(0.025,0.975))
summary(hhFinalFraction2); quantile(hhFinalFraction2,c(0.025,0.975))

# Household final fraction per household size
hhFinalFraction1_hhsize = model1$hhFinalFraction_hhsize[sel1,]
hhFinalFraction2_hhsize = model2$hhFinalFraction_hhsize[sel2,]
llim <- min(c(hhFinalFraction1_hhsize, hhFinalFraction2_hhsize))
ulim <- max(c(hhFinalFraction1_hhsize, hhFinalFraction2_hhsize))
windows(record=T,width=15, height=5)
par(mfrow= c(1,3))
boxplot(hhFinalFraction1_hhsize[,1], hhFinalFraction2_hhsize[,1], ylim = c(llim, ulim), main = "Household size 2", names = c(abbrev1, abbrev2), ylab = "Proportion households affected", boxwex = 0.5, notch = TRUE)
boxplot(hhFinalFraction1_hhsize[,2], hhFinalFraction2_hhsize[,2], ylim = c(llim, ulim), main = "Household size 3", names = c(abbrev1, abbrev2), ylab = "Proportion households affected", boxwex = 0.5, notch = TRUE)
boxplot(hhFinalFraction1_hhsize[,3], hhFinalFraction2_hhsize[,3], ylim = c(llim, ulim), main = "Household size 4", names = c(abbrev1, abbrev2), ylab = "Proportion households affected", boxwex = 0.5, notch = TRUE)
savePlot(filename = paste("hhFinalFraction_hhsize_boxplot1", "_", abbrev1, "_", abbrev2, name, ".jpg", sep=""), type = "jpg", restoreConsole = TRUE)
dev.off()
windows(record=T,width=15, height=5)
par(mfrow= c(1,3))
boxplot(hhFinalFraction1_hhsize[,4], hhFinalFraction2_hhsize[,4], ylim = c(llim, ulim), main = "Household size 5", names = c(abbrev1, abbrev2), ylab = "Proportion households affected", boxwex = 0.5, notch = TRUE)
boxplot(hhFinalFraction1_hhsize[,5], hhFinalFraction2_hhsize[,5], ylim = c(llim, ulim), main = "Household size >=6", names = c(abbrev1, abbrev2), ylab = "Proportion households affected", boxwex = 0.5, notch = TRUE)
boxplot(hhFinalFraction1, hhFinalFraction2, ylim = c(llim, ulim), main = "Total", names = c(abbrev1, abbrev2), ylab = "Proportion households affected", boxwex = 0.5, notch = TRUE)
savePlot(filename = paste("hhFinalFraction_hhsize_boxplot2", "_", abbrev1, "_", abbrev2, name, ".jpg", sep=""), type = "jpg", restoreConsole = TRUE)
dev.off()
# Quantile plots 
windows(record=T,width=15, height=5)
par(mfrow= c(1,3))
qqplot(hhFinalFraction1_hhsize[,1], hhFinalFraction2_hhsize[,1], xlab=abbrev1, ylab=abbrev2, main = "Proportion households affected - Household size 2"); abline(0,1)
qqplot(hhFinalFraction1_hhsize[,2], hhFinalFraction2_hhsize[,2], xlab=abbrev1, ylab=abbrev2, main = "Proportion households affected - Household size 3"); abline(0,1)
qqplot(hhFinalFraction1_hhsize[,3], hhFinalFraction2_hhsize[,3], xlab=abbrev1, ylab=abbrev2, main = "Proportion households affected - Household size 4"); abline(0,1)
savePlot(filename = paste("hhFinalFraction_hhsize_qqplot1", "_", abbrev1, "_", abbrev2, name, ".jpg", sep=""), type = "jpg", restoreConsole = TRUE)
dev.off()
windows(record=T,width=15, height=5)
par(mfrow= c(1,3))
qqplot(hhFinalFraction1_hhsize[,4], hhFinalFraction2_hhsize[,4], xlab=abbrev1, ylab=abbrev2, main = "Proportion households affected - Household size 5"); abline(0,1)
qqplot(hhFinalFraction1_hhsize[,5], hhFinalFraction2_hhsize[,5], xlab=abbrev1, ylab=abbrev2, main = "Proportion households affected - Household size >=6"); abline(0,1)
qqplot(hhFinalFraction1, hhFinalFraction2, xlab=abbrev1, ylab=abbrev2, main = "Proportion households affected - Total"); abline(0,1)
savePlot(filename = paste("hhFinalFraction_hhsize_qqplot2", "_", abbrev1, "_", abbrev2, name, ".jpg", sep=""), type = "jpg", restoreConsole = TRUE)
dev.off()

# Mean infectious period
summary(model1$infPeriod)
summary(model2$infPeriod)

# Community probability of infection (CPI)
# Children <=18y
summary(model1$CPIchild)
summary(model2$CPIchild)
# Adults >18y
summary(model1$CPIadult)
summary(model2$CPIadult)

# Number of cases per time step
timeSteps <- 150
sampleSize <- 50
cases1 <- model1$cases[sel1, ]
cases2 <- model2$cases[sel2, ]
ulim <- max(c(cases1, cases2),na.rm=T)
#par(mfrow= c(2,2))
windows(record=T,width=10, height=5)
par(mfrow= c(1,2))
plotSimIncidence(cases1, timeSteps, sampleSize, main = "", ylab = "Number of cases", ylim = c(0, ulim), color = "grey", transparency = 1, width = 0.6)
plotSimIncidence(cases2, timeSteps, sampleSize, main = "", ylab = "Number of cases", ylim = c(0, ulim), color = "grey", transparency = 1, width = 0.6)
savePlot(filename = paste("cases_total", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
savePlot(filename = paste("cases_total", "_", abbrev1, "_", abbrev2, name, ".jpg", sep=""), type = "jpg", restoreConsole = TRUE)
dev.off()
# stacked plot
sel = 1:timeSteps
meancases1 = apply(cases1,2,mean,na.rm=T); cicases1 = apply(cases1,2,quantile,na.rm=T,c(0.05,0.95))
meancases2 = apply(cases2,2,mean,na.rm=T); cicases2 = apply(cases2,2,quantile,na.rm=T,c(0.05,0.95))
windows(record=T)
par(mfrow= c(1,1))
ulim <- 1.2*max(c(cicases1[sel], cicases2[sel]),na.rm=T)
plot(meancases1[sel], lwd = 2, type = "l", ylab = "Number of cases", xlab = "Time", ylim = c(0, ulim))
lines(cicases1[1,sel],lty=2); lines(cicases1[2,sel],lty=2)
lines(meancases2[sel], lwd = 2,col="red")
lines(cicases2[1,sel],lty=2); lines(cicases2[2,sel],lty=2, col="red")
legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
savePlot(filename = paste("casesMean", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
savePlot(filename = paste("casesMean", "_", abbrev1, "_", abbrev2, name, ".jpg", sep=""), type = "jpg", restoreConsole = TRUE)
dev.off()


# Incidence per time step
timeSteps <- 150
sampleSize <- 50
incidence1 <- model1$incidence[sel1, ]
incidence2 <- model2$incidence[sel2, ]
hhIncidence1 <- model1$hhIncidence[sel1, ]
hhIncidence2 <- model2$hhIncidence[sel2, ]
ulim <- max(c(incidence1, incidence2))
ulim_hh <- max(c(hhIncidence1, hhIncidence2))
#par(mfrow= c(2,2))
windows(record=T,width=10, height=5)
par(mfrow= c(1,2))
plotSimIncidence(incidence1, timeSteps, sampleSize, main = name1, ylab = "Total incidence", ylim = c(0, ulim), color = "grey", transparency = 1, width = 0.6)
plotSimIncidence(incidence2, timeSteps, sampleSize, main = name2, ylab = "Total incidence", ylim = c(0, ulim), color = "grey", transparency = 1, width = 0.6)
savePlot(filename = paste("incidence_total", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off()
windows(record=T,width=10, height=5)
par(mfrow= c(1,2))
plotSimIncidence(hhIncidence1, timeSteps, sampleSize, main = name1, ylab = "Household incidence", ylim = c(0, ulim_hh), color = "grey", transparency = 1, width = 0.6)
plotSimIncidence(hhIncidence2, timeSteps, sampleSize, main = name2, ylab = "Household incidence", ylim = c(0, ulim_hh), color = "grey", transparency = 1, width = 0.6)
savePlot(filename = paste("incidence_hh", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off()
# stacked plot
sel = 1:timeSteps
meanIncidence1 = apply(incidence1,2,mean,na.rm=T); ciIncidence1 = apply(incidence1,2,quantile,na.rm=T,c(0.025,0.975))
meanIncidence2 = apply(incidence2,2,mean,na.rm=T); ciIncidence2 = apply(incidence2,2,quantile,na.rm=T,c(0.025,0.975))
meanhhIncidence1 = apply(hhIncidence1,2,mean,na.rm=T); cihhIncidence1 = apply(hhIncidence1,2,quantile,na.rm=T,c(0.025,0.975))
meanhhIncidence2 = apply(hhIncidence2,2,mean,na.rm=T); cihhIncidence2 = apply(hhIncidence2,2,quantile,na.rm=T,c(0.025,0.975))
windows(record=T,width=10, height=5)
par(mfrow= c(1,2))
ulim <- 1.2*max(c(meanIncidence1[sel], meanIncidence2[sel]),na.rm=T)
plot(meanIncidence1[sel], lwd = 2, type = "l", ylab = "Total incidence", xlab = "Time", ylim = c(0, ulim))
#lines(ciIncidence1[1,sel],lty=2); lines(ciIncidence1[2,sel],lty=2)
lines(meanIncidence2[sel], lwd = 2,col="red")
#legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
ulim <- 1.2*max(c(meanhhIncidence1[sel], meanhhIncidence2[sel]),na.rm=T)
plot(meanhhIncidence1[sel], lwd = 2, type = "l", ylab = "Household incidence", xlab = "Time", ylim = c(0, ulim))
lines(meanhhIncidence2[sel], lwd = 2,col="red")
#legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
savePlot(filename = paste("incidenceMean", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off()
# stacked plot: median
sel = 1:timeSteps
meanIncidence1 = apply(incidence1,2,median,na.rm=T); ciIncidence1 = apply(incidence1,2,quantile,na.rm=T,c(0.05,0.95))
meanIncidence2 = apply(incidence2,2,median,na.rm=T); ciIncidence2 = apply(incidence2,2,quantile,na.rm=T,c(0.05,0.95))
meanhhIncidence1 = apply(hhIncidence1,2,median,na.rm=T); cihhIncidence1 = apply(hhIncidence1,2,quantile,na.rm=T,c(0.05,0.95))
meanhhIncidence2 = apply(hhIncidence2,2,median,na.rm=T); cihhIncidence2 = apply(hhIncidence2,2,quantile,na.rm=T,c(0.05,0.95))
windows(record=T,width=10, height=5)
par(mfrow= c(1,2))
ulim <- 1.2*max(c(ciIncidence1[sel], ciIncidence2[sel]),na.rm=T)
plot(meanIncidence1[sel], lwd = 2, type = "l", ylab = "Total incidence", xlab = "Time", ylim = c(0, ulim))
lines(ciIncidence1[1,sel],lty=2); lines(ciIncidence1[2,sel],lty=2)
lines(meanIncidence2[sel], lwd = 2,col="red")
legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
ulim <- 1.2*max(c(cihhIncidence1[sel], cihhIncidence2[sel]),na.rm=T)
plot(meanhhIncidence1[sel], lwd = 2, type = "l", ylab = "Household incidence", xlab = "Time", ylim = c(0, ulim))
lines(cihhIncidence1[1,sel],lty=2); lines(cihhIncidence1[2,sel],lty=2)
lines(meanhhIncidence2[sel], lwd = 2,col="red")
legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))


## Incidence per household size per time step
sampleSize <- 50
hhIncidence1_hhsize <- model1$hhIncidence_hhsize[,,sel1]
hhIncidence2_hhsize <- model2$hhIncidence_hhsize[,,sel2]
ulim_hh <- max(c(hhIncidence1_hhsize, hhIncidence2_hhsize),na.rm=T)
windows(record=T,width=7, height=5)
par(mfrow= c(3,2))
plotSimIncidence(t(hhIncidence1_hhsize[1,,]), timeSteps, sampleSize, main = paste("Household size 2 - ",name1), ylab = "Household incidence", ylim = c(0, ulim_hh), color = "grey", transparency = 1, width = 0.6)
plotSimIncidence(t(hhIncidence2_hhsize[1,,]), timeSteps, sampleSize, main = paste("Household size 2 - ",name2), ylab = "Household incidence", ylim = c(0, ulim_hh), color = "grey", transparency = 1, width = 0.6)
plotSimIncidence(t(hhIncidence1_hhsize[2,,]), timeSteps, sampleSize, main = paste("Household size 3 - ",name1), ylab = "Household incidence", ylim = c(0, ulim_hh), color = "grey", transparency = 1, width = 0.6)
plotSimIncidence(t(hhIncidence2_hhsize[2,,]), timeSteps, sampleSize, main = paste("Household size 3 - ",name2), ylab = "Household incidence", ylim = c(0, ulim_hh), color = "grey", transparency = 1, width = 0.6)
plotSimIncidence(t(hhIncidence1_hhsize[3,,]), timeSteps, sampleSize, main = paste("Household size 4 - ",name1), ylab = "Household incidence", ylim = c(0, ulim_hh), color = "grey", transparency = 1, width = 0.6)
plotSimIncidence(t(hhIncidence2_hhsize[3,,]), timeSteps, sampleSize, main = paste("Household size 4 - ",name2), ylab = "Household incidence", ylim = c(0, ulim_hh), color = "grey", transparency = 1, width = 0.6)
savePlot(filename = paste("incidence_hh_hhsize1", "_", abbrev1, "_", abbrev2, name, ".jpg", sep=""), type = "jpg", restoreConsole = TRUE)
dev.off()
windows(record=T,width=7, height=5)
par(mfrow= c(3,2))
plotSimIncidence(hhIncidence1_hhsize[4,,], timeSteps, sampleSize, main = paste("Household size 5 - ",name1), ylab = "Household incidence", ylim = c(0, ulim_hh), color = "grey", transparency = 1, width = 0.6)
plotSimIncidence(hhIncidence2_hhsize[4,,], timeSteps, sampleSize, main = paste("Household size 5 - ",name2), ylab = "Household incidence", ylim = c(0, ulim_hh), color = "grey", transparency = 1, width = 0.6)
plotSimIncidence(hhIncidence1_hhsize[5,,], timeSteps, sampleSize, main = paste("Household size >=6 - ",name1), ylab = "Household incidence", ylim = c(0, ulim_hh), color = "grey", transparency = 1, width = 0.6)
plotSimIncidence(hhIncidence2_hhsize[5,,], timeSteps, sampleSize, main = paste("Household size >=6 - ",name2), ylab = "Household incidence", ylim = c(0, ulim_hh), color = "grey", transparency = 1, width = 0.6)
plotSimIncidence(hhIncidence1, timeSteps, sampleSize, main = paste("Total - ",name1), ylab = "Household incidence", ylim = c(0, ulim_hh), color = "grey", transparency = 1, width = 0.6)
plotSimIncidence(hhIncidence2, timeSteps, sampleSize, main = paste("Total - ",name2), ylab = "Household incidence", ylim = c(0, ulim_hh), color = "grey", transparency = 1, width = 0.6)
savePlot(filename = paste("incidence_hh_hhsize2", "_", abbrev1, "_", abbrev2, name, ".jpg", sep=""), type = "jpg", restoreConsole = TRUE)
dev.off()
## stacked plot
sel = 1:timeSteps
meanIncidence1 = apply(hhIncidence1_hhsize,c(1,2),mean,na.rm=T)
meanIncidence2 = apply(hhIncidence2_hhsize,c(1,2),mean,na.rm=T)
windows(record=T,width=15, height=5)
par(mfrow= c(1,3))
ulim_hh <- 1.2*max(c(meanIncidence1[1,sel], meanIncidence2[1,sel]),na.rm=T)
plot(meanIncidence1[1,sel], lwd = 2, type = "l", main = "Household size 2", ylab = "Household incidence", xlab = "Time", ylim = c(0, ulim_hh))
lines(meanIncidence2[1,sel], lwd = 2,col="red")
legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
ulim_hh <- 1.2*max(c(meanIncidence1[2,sel], meanIncidence2[2,sel]),na.rm=T)
plot(meanIncidence1[2,sel], lwd = 2, type = "l", main = "Household size 3", ylab = "Household incidence", xlab = "Time", ylim = c(0, ulim_hh))
lines(meanIncidence2[2,sel], lwd = 2,col="red")
legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
ulim_hh <- 1.2*max(c(meanIncidence1[3,sel], meanIncidence2[3,sel]),na.rm=T)
plot(meanIncidence1[3,sel], lwd = 2, type = "l", main = "Household size 4", ylab = "Household incidence", xlab = "Time", ylim = c(0, ulim_hh))
lines(meanIncidence2[3,sel], lwd = 2,col="red")
legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
savePlot(filename = paste("incidence_hh_hhsize_mean1", "_", abbrev1, "_", abbrev2, name, ".jpg", sep=""), type = "jpg", restoreConsole = TRUE)
dev.off()
windows(record=T,width=15, height=5)
par(mfrow= c(1,3))
ulim_hh <- 1.2*max(c(meanIncidence1[4,sel], meanIncidence2[4,sel]),na.rm=T)
plot(meanIncidence1[4,sel], lwd = 2, type = "l", main = "Household size 5", ylab = "Household incidence", xlab = "Time", ylim = c(0, ulim_hh))
lines(meanIncidence2[4,sel], lwd = 2,col="red")
legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
ulim_hh <- 1.2*max(c(meanIncidence1[5,sel], meanIncidence2[5,sel]),na.rm=T)
plot(meanIncidence1[5,sel], lwd = 2, type = "l", main = "Household size >=6", ylab = "Household incidence", xlab = "Time", ylim = c(0, ulim_hh))
lines(meanIncidence2[5,sel], lwd = 2,col="red")
legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
ulim_hh <- 1.2*max(c(apply(hhIncidence1,2,mean,na.rm=T)[sel], apply(hhIncidence2,2,mean,na.rm=T)[sel]),na.rm=T)
plot(apply(hhIncidence1,2,mean,na.rm=T)[sel], lwd = 2, type = "l", main = "Total", ylab = "Household incidence", xlab = "Time", ylim = c(0, ulim_hh))
lines(apply(hhIncidence2,2,mean,na.rm=T)[sel], lwd = 2,col="red")
legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
savePlot(filename = paste("incidence_hh_hhsize_mean2", "_", abbrev1, "_", abbrev2, name, ".jpg", sep=""), type = "jpg", restoreConsole = TRUE)
dev.off()

# Incidence for children, fathers, mothers
# Children
incidenceChild1 <- model1$incidenceChild[sel1, 1:timeSteps]
incidenceChild2 <- model2$incidenceChild[sel2, 1:timeSteps]
meanIncidenceChild1 <- apply(incidenceChild1, 2, mean)
meanIncidenceChild2 <- apply(incidenceChild2, 2, mean)
# Fathers
incidenceFather1 <- model1$incidenceFather[sel1, 1:timeSteps]
incidenceFather2 <- model2$incidenceFather[sel2, 1:timeSteps]
meanIncidenceFather1 <- apply(incidenceFather1, 2, mean)
meanIncidenceFather2 <- apply(incidenceFather2, 2, mean)
# Mothers
incidenceMother1 <- model1$incidenceMother[sel1, 1:timeSteps]
incidenceMother2 <- model2$incidenceMother[sel2, 1:timeSteps]
meanIncidenceMother1 <- apply(incidenceMother1, 2, mean)
meanIncidenceMother2 <- apply(incidenceMother2, 2, mean)
# Figure
windows(record=T,width=10, height=5)
par(mfrow= c(1,2))
ulim <- max(c(meanIncidenceChild1, meanIncidenceFather1, meanIncidenceMother1))
plot(meanIncidenceChild1, main = name1, ylab = "Total incidence", type = "l", ylim = c(0, ulim), lwd = 2, col = "black")
lines(meanIncidenceFather1, lwd = 2, col = "blue")
lines(meanIncidenceMother1, lwd = 2, col = "red")
legend("topright", legend = c("Children", "Fathers", "Mothers"), lty = 1, col = c("black", "blue", "red"), lwd = 2)
ulim <- max(c(meanIncidenceChild2, meanIncidenceFather2, meanIncidenceMother2))
plot(meanIncidenceChild2, main = name2, ylab = "Total incidence", type = "l", ylim = c(0, ulim), lwd = 2, col = "black")
lines(meanIncidenceFather2, lwd = 2, col = "blue")
lines(meanIncidenceMother2, lwd = 2, col = "red")
legend("topright", legend = c("Children", "Fathers", "Mothers"), lty = 1, col = c("black", "blue", "red"), lwd = 2)
savePlot(filename = paste("incidenceCFM", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off()
## stacked
windows(record=T,width=10, height=5)
par(mfrow= c(1,3))
plot(meanIncidenceChild1, main = "Children", ylab = "Total incidence", type = "l", ylim = c(0, max(c(meanIncidenceChild1,meanIncidenceChild2))), lwd = 2, col = "black")
lines(meanIncidenceChild2, col="red")
legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
plot(meanIncidenceFather1, main = "Fathers", ylab = "Total incidence", type = "l", ylim = c(0, max(c(meanIncidenceFather1,meanIncidenceFather2))), lwd = 2, col = "black")
lines(meanIncidenceFather2, col="red")
legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
plot(meanIncidenceMother1, main = "Mothers", ylab = "Total incidence", type = "l", ylim = c(0, max(c(meanIncidenceMother1,meanIncidenceMother2))), lwd = 2, col = "black")
lines(meanIncidenceMother2, col="red")
legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
savePlot(filename = paste("incidenceCFM", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off()

# Attack rate for children, fathers, mothers (fraction ultimately infected)
hh_role <- HH_network %v% "hh_role"
nrChildren <- sum(hh_role == "child")
nrFathers <- sum(hh_role == "father")
nrMothers <-  sum(hh_role == "mother")
propInfectedChild1 <- apply(model1$incidenceChild[sel1,], 1, sum)/nrChildren
propInfectedChild2 <- apply(model2$incidenceChild[sel2,], 1, sum)/nrChildren
propInfectedFather1 <- apply(model1$incidenceFather[sel1,], 1, sum)/nrFathers
propInfectedFather2 <- apply(model2$incidenceFather[sel2,], 1, sum)/nrFathers
propInfectedMother1 <- apply(model1$incidenceMother[sel1,], 1, sum)/nrMothers
propInfectedMother2 <- apply(model2$incidenceMother[sel2,], 1, sum)/nrMothers
# Figure
windows(record=T,width=15, height=5)
par(mfrow= c(1,3))
boxplot(propInfectedChild1, propInfectedChild2, main = "Children", names = c(abbrev1, abbrev2)
		, ylab = "Attack rate", boxwex = 0.6, cex.main = 1, notch = TRUE, ylim = c(llim,1))
boxplot(propInfectedFather1, propInfectedFather2, main = "Fathers", names = c(abbrev1, abbrev2)
		, ylab = "Attack rate", boxwex = 0.6, cex.main = 1, notch = TRUE, ylim = c(llim,1))
boxplot(propInfectedMother1, propInfectedMother2, main = "Mothers", names = c(abbrev1, abbrev2)
		, ylab = "Attack rate", boxwex = 0.6, cex.main = 1, notch = TRUE, ylim = c(llim,1))
savePlot(filename = paste("propInfectedCFM", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off()

# Mean proportion infected per household size
hhPropInfected_hhsize1 <- model1$hhPropInfected_hhsize[sel1, ]
hhPropInfected_hhsize2 <- model2$hhPropInfected_hhsize[sel2, ]
hhPropInfected1 <- model1$hhPropInfected[sel1]
hhPropInfected2 <- model2$hhPropInfected[sel2]
# Summary
apply(hhPropInfected_hhsize1, 2, summary)
apply(hhPropInfected_hhsize2, 2, summary)
llim <- min(c(hhPropInfected_hhsize1, hhPropInfected_hhsize2))
# # Figure: four categories
# windows(record=T)
# par(mfrow=c(2,2))
# boxplot(hhPropInfected_hhsize1[,2], hhPropInfected_hhsize2[,2], main = "Household size 3", names = c(abbrev1, abbrev2)
# 		, ylab = "Household attack rate", boxwex = 0.5, cex.main = 1, notch = TRUE, ylim = c(llim,1))
# boxplot(hhPropInfected_hhsize1[,3], hhPropInfected_hhsize2[,3], main = "Household size 4", names = c(abbrev1, abbrev2)
# 		, ylab = "Household attack rate", boxwex = 0.5, cex.main = 1, notch = TRUE, ylim = c(llim,1))
# boxplot(hhPropInfected_hhsize1[,4], hhPropInfected_hhsize2[,4], main = "Household size 5", names = c(abbrev1, abbrev2)
# 		, ylab = "Household attack rate", boxwex = 0.5, cex.main = 1, notch = TRUE, ylim = c(llim,1))
# boxplot(hhPropInfected1, hhPropInfected2, main = "Total", names = c(abbrev1, abbrev2)
# 		, ylab = "Household attack rate", boxwex = 0.5, cex.main = 1, notch = TRUE, ylim = c(llim,1))
# savePlot(filename = paste("hhPropInfected", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
# dev.off()
# Figure: all categories
windows(record=T,width=15, height=5)
par(mfrow= c(1,3))
boxplot(hhPropInfected_hhsize1[,1], hhPropInfected_hhsize2[,1], main = "Household size 2", names = c(abbrev1,abbrev2)
		, ylab = "Household attack rate", boxwex = 0.6, cex.main = 1, notch = TRUE, ylim = c(llim,1))
boxplot(hhPropInfected_hhsize1[,2], hhPropInfected_hhsize2[,2], main = "Household size 3", names = c(abbrev1,abbrev2)
		, ylab = "Household attack rate", boxwex = 0.6, cex.main = 1, notch = TRUE, ylim = c(llim,1))
boxplot(hhPropInfected_hhsize1[,3], hhPropInfected_hhsize2[,3], main = "Household size 4", names = c(abbrev1,abbrev2)
		, ylab = "Household attack rate", boxwex = 0.6, cex.main = 1, notch = TRUE, ylim = c(llim,1))
savePlot(filename = paste("hhPropInfected1", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off()
windows(record=T,width=15, height=5)
par(mfrow= c(1,3))
boxplot(hhPropInfected_hhsize1[,4], hhPropInfected_hhsize2[,4], main = "Household size 5", names = c(abbrev1, abbrev2)
		, ylab = "Household attack rate", boxwex = 0.6, cex.main = 1, notch = TRUE, ylim = c(llim,1))
boxplot(hhPropInfected_hhsize1[,5], hhPropInfected_hhsize2[,5], main = "Household size >=6", names = c(abbrev1,abbrev2)
		, ylab = "Household attack rate", boxwex = 0.6, cex.main = 1, notch = TRUE, ylim = c(llim,1))
boxplot(hhPropInfected1, hhPropInfected2, main = "Total", names = c(abbrev1, abbrev2)
		, ylab = "Household attack rate", boxwex = 0.6, cex.main = 1, notch = TRUE, ylim = c(llim,1))
savePlot(filename = paste("hhPropInfected2", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off()
# On one figure
n1=dim(hhPropInfected_hhsize1)[1]
n2=dim(hhPropInfected_hhsize2)[1]
dat.tmp = data.frame(prop=c(c(hhPropInfected_hhsize1),hhPropInfected1,c(hhPropInfected_hhsize2),hhPropInfected2),hhsize=c(rep("2",n1),rep("3",n1),rep("4",n1),rep("5",n1),rep(">=6",n1),rep("Total",n1),rep("2",n2),rep("3",n2),rep("4",n2),rep("5",n2),rep(">=6",n2),rep("Total",n2)),mixing=c(rep(abbrev1,6*n1),rep(abbrev2,6*n2)))
dat.tmp$hhsize=factor(dat.tmp$hhsize,c("2","3","4","5",">=6","Total"))
dat.tmp$mixing=factor(dat.tmp$mixing,c(abbrev1,abbrev2))
windows(record=T,width=15, height=5)
boxplot(prop~mixing+hhsize,data=dat.tmp,axes=F,boxwex=0.4,notch=T,cex.main=1,at=c(0.4,1,2,2.6,3.6,4.2,5.2,5.8,6.8,7.4,8.4,9),ylab = "Household attack rate",xlab="Household size",col=c("white","gray"))
axis(2)
axis(1,at=c(0.7,2.3,3.9,5.5,7.1,8.7),labels=c("2","3","4","5",">=6","Total"))
box()
savePlot(filename = paste("hhPropInfected", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
savePlot(filename = paste("hhPropInfected", "_", abbrev1, "_", abbrev2, name, ".jpg", sep=""), type = "jpg", restoreConsole = TRUE)
dev.off()

# Quantile plots
windows(record=T,width=15, height=5)
par(mfrow= c(1,3))
qqplot(hhPropInfected_hhsize1[,1], hhPropInfected_hhsize2[,1], xlab = abbrev1, ylab = abbrev2, main = "Household size 2"); abline(0,1)
qqplot(hhPropInfected_hhsize1[,2], hhPropInfected_hhsize2[,2], xlab = abbrev1, ylab = abbrev2, main = "Household size 3"); abline(0,1)
qqplot(hhPropInfected_hhsize1[,3], hhPropInfected_hhsize2[,3], xlab = abbrev1, ylab = abbrev2, main = "Household size 4"); abline(0,1)
savePlot(filename = paste("hhPropInfected1_qqplot", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off()
windows(record=T,width=15, height=5)
par(mfrow= c(1,3))
qqplot(hhPropInfected_hhsize1[,4], hhPropInfected_hhsize2[,4], xlab = abbrev1, ylab = abbrev2, main = "Household size 5"); abline(0,1)
qqplot(hhPropInfected_hhsize1[,5], hhPropInfected_hhsize2[,5], xlab = abbrev1, ylab = abbrev2, main = "Household size >=6"); abline(0,1)
qqplot(hhPropInfected1, hhPropInfected2, xlab = abbrev1, ylab = abbrev2, main = "Total"); abline(0,1)
savePlot(filename = paste("hhPropInfected2_qqplot", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off()

# Mean proportion secundary cases per household size
hhSecInfected_hhsize1 <- model1$hhSecInfected_hhsize[sel1, ]
hhSecInfected_hhsize2 <- model2$hhSecInfected_hhsize[sel2, ]
# Summary
apply(hhSecInfected_hhsize1, 2, summary)
apply(hhSecInfected_hhsize2, 2, summary)
llim <- min(c(hhSecInfected_hhsize1, hhSecInfected_hhsize2),na.rm=T)
# Figure: all categories
windows(record=T,width=15, height=5)
par(mfrow= c(1,3))
boxplot(hhSecInfected_hhsize1[,1], hhSecInfected_hhsize2[,1], main = "Household size 2", names = c(abbrev1,abbrev2)
        , ylab = "Proportion secundary cases", boxwex = 0.6, cex.main = 1, notch = TRUE, ylim = c(llim,1))
boxplot(hhSecInfected_hhsize1[,2], hhSecInfected_hhsize2[,2], main = "Household size 3", names = c(abbrev1,abbrev2)
        , ylab = "Proportion secundary cases", boxwex = 0.6, cex.main = 1, notch = TRUE, ylim = c(llim,1))
boxplot(hhSecInfected_hhsize1[,3], hhSecInfected_hhsize2[,3], main = "Household size 4", names = c(abbrev1,abbrev2)
        , ylab = "Proportion secundary cases", boxwex = 0.6, cex.main = 1, notch = TRUE, ylim = c(llim,1))
savePlot(filename = paste("hhSecInfected1", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off()
windows(record=T,width=10, height=5)
par(mfrow= c(1,2))
boxplot(hhSecInfected_hhsize1[,4], hhSecInfected_hhsize2[,4], main = "Household size 5", names = c(abbrev1, abbrev2)
        , ylab = "Proportion secundary cases", boxwex = 0.6, cex.main = 1, notch = TRUE, ylim = c(llim,1))
boxplot(hhSecInfected_hhsize1[,5], hhSecInfected_hhsize2[,5], main = "Household size >=6", names = c(abbrev1,abbrev2)
        , ylab = "Proportion secundary cases", boxwex = 0.6, cex.main = 1, notch = TRUE, ylim = c(llim,1))
savePlot(filename = paste("hhSecInfected2", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off()
# Quantile plots
windows(record=T,width=15, height=5)
par(mfrow= c(1,3))
qqplot(hhSecInfected_hhsize1[,1], hhSecInfected_hhsize2[,1],xlab = abbrev1, ylab = abbrev2, main = "Household size 2"); abline(0,1)
qqplot(hhSecInfected_hhsize1[,2], hhSecInfected_hhsize2[,2],xlab = abbrev1, ylab = abbrev2, main = "Household size 3"); abline(0,1)
qqplot(hhSecInfected_hhsize1[,3], hhSecInfected_hhsize2[,3],xlab = abbrev1, ylab = abbrev2, main = "Household size 4"); abline(0,1)
savePlot(filename = paste("hhSecInfected1_qqplot", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off()
windows(record=T,width=10, height=5)
par(mfrow= c(1,2))
qqplot(hhSecInfected_hhsize1[,4], hhSecInfected_hhsize2[,4],xlab = abbrev1, ylab = abbrev2, main = "Household size 5"); abline(0,1)
qqplot(hhSecInfected_hhsize1[,5], hhSecInfected_hhsize2[,5],xlab = abbrev1, ylab = abbrev2, main = "Household size >=6"); abline(0,1)
savePlot(filename = paste("hhSecInfected2_qqplot", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off()

# Mean time from first onset to the last case per household size
hhDuration_hhsize1 <- model1$hhDuration_hhsize[sel1, ]
hhDuration_hhsize2 <- model2$hhDuration_hhsize[sel2, ]
hhDuration1 <- model1$hhDuration[sel1]
hhDuration2 <- model2$hhDuration[sel2]
llim <- min(c(hhDuration_hhsize1, hhDuration_hhsize2), na.rm = TRUE)
ulim <- max(c(hhDuration_hhsize1, hhDuration_hhsize2), na.rm = TRUE)
windows(record=T,width=15, height=5)
par(mfrow=c(1,3))
boxplot(hhDuration_hhsize1[,2], hhDuration_hhsize2[,2], main = "Household size 3", names = c(abbrev1, abbrev2)
		, ylab = "Mean time 1st -> last case per HH", boxwex = 0.5, cex.main = 1, notch = TRUE, ylim = c(llim,ulim))
boxplot(hhDuration_hhsize1[,3], hhDuration_hhsize2[,3], main = "Household size 4", names = c(abbrev1, abbrev2)
		, ylab = "Mean time 1st -> last case per HH", boxwex = 0.5, cex.main = 1, notch = TRUE, ylim = c(llim,ulim))
boxplot(hhDuration_hhsize1[,4], hhDuration_hhsize2[,4], main = "Household size 5", names = c(abbrev1, abbrev2)
		, ylab = "Mean time 1st -> last case per HH", boxwex = 0.5, cex.main = 1, notch = TRUE, ylim = c(llim,ulim))
savePlot(filename = paste("hhDuration1", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off()
windows(record=T,width=10, height=5)
par(mfrow=c(1,2))
boxplot(hhDuration_hhsize1[,5], hhDuration_hhsize2[,5], main = "Household size >=6", names = c(abbrev1, abbrev2)
        , ylab = "Mean time 1st -> last case per HH", boxwex = 0.5, cex.main = 1, notch = TRUE, ylim = c(llim,ulim))
boxplot(hhDuration1, hhDuration2, main = "Total", names = c(abbrev1, abbrev2)
		, ylab = "Mean time 1st -> last case per HH", boxwex = 0.5, cex.main = 1, notch = TRUE, ylim = c(llim,ulim))
savePlot(filename = paste("hhDuration2", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off()
# Quantile plots
windows(record=T,width=15, height=5)
par(mfrow=c(1,3))
qqplot(hhDuration_hhsize1[,2], hhDuration_hhsize2[,2], xlab = abbrev1, ylab = abbrev2, main = "Household size 3"); abline(0,1)
qqplot(hhDuration_hhsize1[,3], hhDuration_hhsize2[,3], xlab = abbrev1, ylab = abbrev2, main = "Household size 4"); abline(0,1)
qqplot(hhDuration_hhsize1[,4], hhDuration_hhsize2[,4], xlab = abbrev1, ylab = abbrev2, main = "Household size 5"); abline(0,1)
savePlot(filename = paste("hhDuration1_qqplot", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off()
windows(record=T,width=10, height=5)
par(mfrow=c(1,2))
qqplot(hhDuration_hhsize1[,5], hhDuration_hhsize2[,5], xlab = abbrev1, ylab = abbrev2, main = "Household size >=6"); abline(0,1)
qqplot(hhDuration1, hhDuration2, xlab = abbrev1, ylab = abbrev2, main = "Total"); abline(0,1)
savePlot(filename = paste("hhDuration2_qqplot", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off()

# Mean proportion infected per role index case
hhPropInfected_role1 <- model1$hhPropInfected_role[sel1, ]
hhPropInfected_role2 <- model2$hhPropInfected_role[sel2, ]
hhPropInfected1 <- model1$hhPropInfected[sel1]
hhPropInfected2 <- model2$hhPropInfected[sel2]
# Summary
apply(hhPropInfected_role1, 2, summary)
apply(hhPropInfected_role2, 2, summary)
llim <- min(c(hhPropInfected_role1, hhPropInfected_role2))
# On one figure
n1=dim(hhPropInfected_hhsize1)[1]
n2=dim(hhPropInfected_hhsize2)[1]
dat.tmp = data.frame(prop=c(c(hhPropInfected_role1),hhPropInfected1,c(hhPropInfected_role2),hhPropInfected2),role=c(rep("father",n1),rep("mother",n1),rep("child",n1),rep("Total",n1),rep("father",n2),rep("mother",n2),rep("child",n2),rep("Total",n2)),mixing=c(rep(abbrev1,4*n1),rep(abbrev2,4*n2)))
dat.tmp$mixing=factor(dat.tmp$mixing,c(abbrev1,abbrev2))
windows(record=T,width=15, height=5)
boxplot(prop~mixing+role,data=dat.tmp,axes=F,boxwex=0.4,notch=T,cex.main=1,at=c(0.4,1,2,2.6,3.6,4.2,5.2,5.8),ylab = "Household attack rate",xlab="Household role",col=c("white","gray"))
axis(2)
axis(1,at=c(0.7,2.3,3.9,5.5),labels=c("father","mother","child","Total"))
box()
dev.off()

# Mean time from first onset to the last case per role index case
hhDuration_role1 <- model1$hhDuration_role[sel1, ]
hhDuration_role2 <- model2$hhDuration_role[sel2, ]
hhDuration1 <- model1$hhDuration[sel1]
hhDuration2 <- model2$hhDuration[sel2]
llim <- min(c(hhDuration_role1, hhDuration_role2), na.rm = TRUE)
ulim <- max(c(hhDuration_role1, hhDuration_role2), na.rm = TRUE)
# Summary
apply(hhDuration_role1, 2, summary)
apply(hhDuration_role2, 2, summary)
llim <- min(c(hhDuration_role1, hhDuration_role2))
# On one figure
n1=dim(hhDuration_role1)[1]
n2=dim(hhDuration_role2)[1]
dat.tmp = data.frame(prop=c(c(hhDuration_role1),hhDuration1,c(hhDuration_role2),hhDuration2),role=c(rep("father",n1),rep("mother",n1),rep("child",n1),rep("Total",n1),rep("father",n2),rep("mother",n2),rep("child",n2),rep("Total",n2)),mixing=c(rep(abbrev1,4*n1),rep(abbrev2,4*n2)))
dat.tmp$mixing=factor(dat.tmp$mixing,c(abbrev1,abbrev2))
windows(record=T,width=15, height=5)
boxplot(prop~mixing+role,data=dat.tmp,axes=F,boxwex=0.4,notch=T,cex.main=1,at=c(0.4,1,2,2.6,3.6,4.2,5.2,5.8),ylab = "Mean time 1st -> last case per HH",xlab="Household role",col=c("white","gray"))
axis(2)
axis(1,at=c(0.7,2.3,3.9,5.5),labels=c("father","mother","child","Total"))
box()
dev.off()

# Index case
counts1 <- table(model1$hhIndexCase[sel1,])
counts2 <- table(model2$hhIndexCase[sel2,])
counts <- prop.table(cbind(counts1, counts2), 2)
windows(record=T)
par(xpd=T, mar=par()$mar+c(0,0,0,6))
bp = barplot(counts, main = "Index Case", names.arg = c(abbrev1, abbrev2), ylab = "Frequency", col = rainbow(3), space = 0.1, cex.axis = 1, cex.names = 1, cex.lab = 1, cex.main = 1, las = 1) 
legend(2.3, 1.0, c("Child", "Father", "Mother"), cex = 1.0, fill = rainbow(3))
savePlot(filename = paste("bar_indexCase", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off()

# Index case: boxplots
counts1 <- apply(model1$hhIndexCase[sel1,],1,function(x)table(factor(x,,levels=c("child","father","mother")))); counts1 <- apply(counts1,2,prop.table)
counts2 <- apply(model2$hhIndexCase[sel2,],1,function(x)table(factor(x,,levels=c("child","father","mother")))); counts2 <- apply(counts2,2,prop.table)
names = c("Child", "Father", "Mother")
## total network
#prop = c(0.5150079,0.2330174,0.2464455)
## week network
prop = c(464/895,210/895,221/895)
windows(record=T,width=10, height=5)
par(mfrow= c(1,3))
for (i in 1:3){
  boxplot(counts1[i,],counts2[i,],main = paste("Index ",names[i]), names = c(abbrev1, abbrev2)
          , ylab = "Frequency", boxwex = 0.6, cex.main = 1, notch = F)
  points(c(prop[i],prop[i]), pch = 8, lwd = 1.8,, col = "blue")
}
savePlot(filename = paste("boxplot_indexCase", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off()

# Last cases
counts1 <- table(model1$hhLastCase)
counts2 <- table(model2$hhLastCase)
counts <- prop.table(cbind(counts1, counts2), 2)
windows(record=T)
par(xpd=T, mar=par()$mar+c(0,0,0,6))
barplot(counts, main = "Last Case", names.arg = c(abbrev1, abbrev2), ylab = "Frequency", col = rainbow(3), space = 0.1, cex.axis = 1, cex.names = 1, cex.lab = 1, cex.main = 1, las = 1) 
legend(2.3, 1.0, c("Child", "Father", "Mother"), cex = 1.0, fill = rainbow(3))
savePlot(filename = paste("bar_lastCase", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off()

# # Index case ALL
# counts1 <- apply(model1$hhIndexCaseAll[sel1,],1,function(x)table(factor(x,,levels=c("child","father","mother")))); counts1 <- apply(counts1,2,prop.table)
# counts2 <- apply(model2$hhIndexCaseAll[sel2,],1,function(x)table(factor(x,,levels=c("child","father","mother")))); counts2 <- apply(counts2,2,prop.table)
# names = c("Child", "Father", "Mother")
# ## total network
# #prop = c(0.5150079,0.2330174,0.2464455)
# ## week network
# prop = c(464/895,210/895,221/895)
# windows(record=T,width=10, height=5)
# par(mfrow= c(1,3))
# for (i in 1:3){
#   boxplot(counts1[,i],counts2[,i],main = paste("Index ",names[i]), names = c(abbrev1, abbrev2)
#           , ylab = "Frequency", boxwex = 0.6, cex.main = 1, notch = F)
#   points(c(prop[i],prop[i]), pch = 8, lwd = 1.8,, col = "blue")
# }
# savePlot(filename = paste("boxplot_indexCaseAll", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
# dev.off()

# ## Distribution number of cases per household size
# cases = c(c(sapply(c("0","1","2","3","4","5",">=6"),rep,sum(sel1))),c(sapply(c("0","1","2","3","4","5",">=6"),rep,sum(sel2))))
# model = c(rep(abbrev1,sum(sel1)*7),rep(abbrev2,sum(sel2)*7))
# dat2 = data.frame(count=c(c(t(model1$hhInfectedTable_hhsize[1,,sel1])),c(t(model2$hhInfectedTable_hhsize[1,,sel2]))),cases=cases,model=model)
# dat2$cases = factor(dat2$cases,levels(dat2$cases)[c(2:7,1)])
# dat3 = data.frame(count=c(c(t(model1$hhInfectedTable_hhsize[2,,sel1])),c(t(model2$hhInfectedTable_hhsize[2,,sel2]))),cases=cases,model=model)
# dat3$cases = factor(dat3$cases,levels(dat3$cases)[c(2:7,1)])
# dat4 = data.frame(count=c(c(t(model1$hhInfectedTable_hhsize[3,,sel1])),c(t(model2$hhInfectedTable_hhsize[3,,sel2]))),cases=cases,model=model)
# dat4$cases = factor(dat4$cases,levels(dat4$cases)[c(2:7,1)])
# dat5 = data.frame(count=c(c(t(model1$hhInfectedTable_hhsize[4,,sel1])),c(t(model2$hhInfectedTable_hhsize[4,,sel2]))),cases=cases,model=model)
# dat5$cases = factor(dat5$cases,levels(dat5$cases)[c(2:7,1)])
# dat6 = data.frame(count=c(c(t(model1$hhInfectedTable_hhsize[5,,sel1])),c(t(model2$hhInfectedTable_hhsize[5,,sel2]))),cases=cases,model=model)
# dat6$cases = factor(dat6$cases,levels(dat6$cases)[c(2:7,1)])
# 
# windows(record=T,width=7, height=5)
# par(mfrow= c(1,1))
# boxplot(count~model*cases,data=dat2, main = "Household size 2",col=c("white","gray"),xlab="Number of cases", ylab = "Frequency", boxwex = 0.6, cex.main = 1, notch = F,xaxt="n")
# axis(1,at=seq(1.5,13.5,2),labels=c("0","1","2","3","4","5",">=6"))       
# legend("topright",fill=c("white","gray"),levels(dat2$model))
# savePlot(filename = paste("distribution_cases_HHsize2", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
# dev.off()
# windows(record=T,width=7, height=5)
# par(mfrow= c(1,1))
# boxplot(count~model*cases,data=dat3, main = "Household size 3",col=c("white","gray"),names = rep(c(abbrev1,abbrev2),7),xlab="Number of cases", ylab = "Frequency", boxwex = 0.6, cex.main = 1, notch = F,xaxt="n")
# axis(1,at=seq(1.5,13.5,2),labels=c("0","1","2","3","4","5",">=6"))       
# legend("topright",fill=c("white","gray"),levels(dat3$model))
# savePlot(filename = paste("distribution_cases_HHsize3", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
# dev.off()
# windows(record=T,width=7, height=5)
# par(mfrow= c(1,1))
# boxplot(count~model*cases,data=dat4, main = "Household size 4",col=c("white","gray"),names = rep(c(abbrev1,abbrev2),7),xlab="Number of cases", ylab = "Frequency", boxwex = 0.6, cex.main = 1, notch = F,xaxt="n")
# axis(1,at=seq(1.5,13.5,2),labels=c("0","1","2","3","4","5",">=6"))       
# legend("topright",fill=c("white","gray"),levels(dat4$model))
# savePlot(filename = paste("distribution_cases_HHsize4", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
# dev.off()
# windows(record=T,width=7, height=5)
# par(mfrow= c(1,1))
# boxplot(count~model*cases,data=dat5, main = "Household size 5",col=c("white","gray"),names = rep(c(abbrev1,abbrev2),7),xlab="Number of cases", ylab = "Frequency", boxwex = 0.6, cex.main = 1, notch = F,xaxt="n")
# axis(1,at=seq(1.5,13.5,2),labels=c("0","1","2","3","4","5",">=6"))       
# legend("topright",fill=c("white","gray"),levels(dat5$model))
# savePlot(filename = paste("distribution_cases_HHsize5", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
# dev.off()
# windows(record=T,width=7, height=5)
# par(mfrow= c(1,1))
# boxplot(count~model*cases,data=dat6, main = "Household size >=6",col=c("white","gray"),names = rep(c(abbrev1,abbrev2),7),xlab="Number of cases", ylab = "Frequency", boxwex = 0.6, cex.main = 1, notch = F,xaxt="n")
# axis(1,at=seq(1.5,13.5,2),labels=c("0","1","2","3","4","5",">=6"))       
# legend(7,12.6,fill=c("white","gray"),levels(dat6$model))
# savePlot(filename = paste("distribution_cases_HHsize6", "_", abbrev1, "_", abbrev2, name, ".eps", sep=""), type = "eps", restoreConsole = TRUE)
# dev.off()

# # Force of infection per time step
# sampleSize <- 50
# hhfoi1 <- model1$hhfoi[sel1, ]
# hhfoi2 <- model2$hhfoi[sel2, ]
# hhulim <- max(c(hhfoi1, hhfoi2),na.rm=T)
# comfoi_child1 <- model1$comfoi_child[sel1, ]
# comfoi_child2 <- model2$comfoi_child[sel2, ]
# com_childulim <- max(c(comfoi_child1, comfoi_child2),na.rm=T)
# comfoi_adult1 <- model1$comfoi_adult[sel1, ]
# comfoi_adult2 <- model2$comfoi_adult[sel2, ]
# com_adultulim <- max(c(comfoi_adult1, comfoi_adult2),na.rm=T)
# ## stacked plot
# sel = 1:timeSteps
# hhfoi1_mean = apply(hhfoi1,2,mean,na.rm=T); hhfoi2_mean = apply(hhfoi2,2,mean,na.rm=T)
# comfoi_child1_mean = apply(comfoi_child1,2,mean,na.rm=T); comfoi_child2_mean = apply(comfoi_child2,2,mean,na.rm=T)
# comfoi_adult1_mean = apply(comfoi_adult1,2,mean,na.rm=T); comfoi_adult2_mean = apply(comfoi_adult2,2,mean,na.rm=T)
# windows(record=T,width=15, height=5)
# par(mfrow= c(1,3))
# ulim_hh <- 1.2*max(c(hhfoi1_mean[sel], hhfoi2_mean[sel]),na.rm=T)
# plot(hhfoi1_mean[sel], lwd = 2, type = "l", main = "Household FOI",ylab="FOI", xlab = "Time", ylim = c(0, ulim_hh))
# lines(hhfoi2_mean[sel], lwd = 2,col="red")
# legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
# ulim_hh <- 1.2*max(c(comfoi_child1_mean[sel], comfoi_child2_mean[sel]),na.rm=T)
# plot(comfoi_child1_mean[sel], lwd = 2, type = "l", main = "Community FOI children",ylab="FOI", xlab = "Time", ylim = c(0, ulim_hh))
# lines(comfoi_child2_mean[sel], lwd = 2,col="red")
# legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
# ulim_hh <- 1.2*max(c(comfoi_adult1_mean[sel], comfoi_adult2_mean[sel]),na.rm=T)
# plot(comfoi_adult1_mean[sel], lwd = 2, type = "l", main = "Community FOI adults",ylab="FOI", xlab = "Time", ylim = c(0, ulim_hh))
# lines(comfoi_adult2_mean[sel], lwd = 2,col="red")
# legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
# savePlot(filename = paste("foi_mean", "_", abbrev1, "_", abbrev2, name, ".jpg", sep=""), type = "jpg", restoreConsole = TRUE)
# dev.off()

# ## HH force of infection per household size per time step
# sampleSize <- 50
# hhfoi1_hhsize <- model1$hhfoi_hhsize[,,sel1]
# hhfoi2_hhsize <- model2$hhfoi_hhsize[,,sel2]
# ulim_hh <- max(c(hhfoi1_hhsize, hhfoi2_hhsize),na.rm=T)
# ## stacked plot
# sel = 1:timeSteps
# meanhhfoi1 = apply(hhfoi1_hhsize,c(1,2),mean,na.rm=T)
# meanhhfoi2 = apply(hhfoi2_hhsize,c(1,2),mean,na.rm=T)
# windows(record=T,width=15, height=5)
# par(mfrow= c(1,3))
# ulim_hh <- 1.2*max(c(meanhhfoi1[1,sel], meanhhfoi2[1,sel]),na.rm=T)
# plot(meanhhfoi1[1,sel], lwd = 2, type = "l", main = "Household size 2", ylab = "Household FOI", xlab = "Time", ylim = c(0, ulim_hh))
# lines(meanhhfoi2[1,sel], lwd = 2,col="red")
# legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
# ulim_hh <- 1.2*max(c(meanhhfoi1[2,sel], meanhhfoi2[2,sel]),na.rm=T)
# plot(meanhhfoi1[2,sel], lwd = 2, type = "l", main = "Household size 3", ylab = "Household FOI", xlab = "Time", ylim = c(0, ulim_hh))
# lines(meanhhfoi2[2,sel], lwd = 2,col="red")
# legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
# ulim_hh <- 1.2*max(c(meanhhfoi1[3,sel], meanhhfoi2[3,sel]),na.rm=T)
# plot(meanhhfoi1[3,sel], lwd = 2, type = "l", main = "Household size 4", ylab = "Household FOI", xlab = "Time", ylim = c(0, ulim_hh))
# lines(meanhhfoi2[3,sel], lwd = 2,col="red")
# legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
# savePlot(filename = paste("hhfoi_hhsize_mean1", "_", abbrev1, "_", abbrev2, name, ".jpg", sep=""), type = "jpg", restoreConsole = TRUE)
# dev.off()
# windows(record=T,width=15, height=5)
# par(mfrow= c(1,3))
# ulim_hh <- 1.2*max(c(meanhhfoi1[4,sel], meanhhfoi2[4,sel]),na.rm=T)
# plot(meanhhfoi1[4,sel], lwd = 2, type = "l", main = "Household size 5", ylab = "Household FOI", xlab = "Time", ylim = c(0, ulim_hh))
# lines(meanhhfoi2[4,sel], lwd = 2,col="red")
# legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
# ulim_hh <- 1.2*max(c(meanhhfoi1[5,sel], meanhhfoi2[5,sel]),na.rm=T)
# plot(meanhhfoi1[5,sel], lwd = 2, type = "l", main = "Household size >=6", ylab = "Household FOI", xlab = "Time", ylim = c(0, ulim_hh))
# lines(meanhhfoi2[5,sel], lwd = 2,col="red")
# legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
# ulim_hh <- 1.2*max(c(apply(hhfoi1,2,mean,na.rm=T)[sel], apply(hhfoi2,2,mean,na.rm=T)[sel]),na.rm=T)
# plot(apply(hhfoi1,2,mean,na.rm=T)[sel], lwd = 2, type = "l", main = "Total", ylab = "Household FOI", xlab = "Time", ylim = c(0, ulim_hh))
# lines(apply(hhfoi2,2,mean,na.rm=T)[sel], lwd = 2,col="red")
# legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
# savePlot(filename = paste("hhfoi_hhsize_mean2", "_", abbrev1, "_", abbrev2, name, ".jpg", sep=""), type = "jpg", restoreConsole = TRUE)
# dev.off()

# ## Community force of infection children per household size per time step
# sampleSize <- 50
# comfoi_child1_hhsize <- model1$comfoi_child_hhsize[,,sel1]
# comfoi_child2_hhsize <- model2$comfoi_child_hhsize[,,sel2]
# ulim_hh <- max(c(comfoi_child1_hhsize, comfoi_child2_hhsize),na.rm=T)
# ## stacked plot
# sel = 1:timeSteps
# meancomfoi_child1 = apply(comfoi_child1_hhsize,c(1,2),mean,na.rm=T)
# meancomfoi_child2 = apply(comfoi_child2_hhsize,c(1,2),mean,na.rm=T)
# windows(record=T,width=15, height=5)
# par(mfrow= c(1,3))
# ulim_hh <- 1.2*max(c(meancomfoi_child1[1,sel], meancomfoi_child2[1,sel]),na.rm=T)
# plot(meancomfoi_child1[1,sel], lwd = 2, type = "l", main = "Household size 2", ylab = "Community FOI children", xlab = "Time", ylim = c(0, ulim_hh))
# lines(meancomfoi_child2[1,sel], lwd = 2,col="red")
# legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
# ulim_hh <- 1.2*max(c(meancomfoi_child1[2,sel], meancomfoi_child2[2,sel]),na.rm=T)
# plot(meancomfoi_child1[2,sel], lwd = 2, type = "l", main = "Household size 3", ylab = "Community FOI children", xlab = "Time", ylim = c(0, ulim_hh))
# lines(meancomfoi_child2[2,sel], lwd = 2,col="red")
# legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
# ulim_hh <- 1.2*max(c(meancomfoi_child1[3,sel], meancomfoi_child2[3,sel]),na.rm=T)
# plot(meancomfoi_child1[3,sel], lwd = 2, type = "l", main = "Household size 4", ylab = "Community FOI children", xlab = "Time", ylim = c(0, ulim_hh))
# lines(meancomfoi_child2[3,sel], lwd = 2,col="red")
# legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
# savePlot(filename = paste("comfoi_child_hhsize_mean1", "_", abbrev1, "_", abbrev2, name, ".jpg", sep=""), type = "jpg", restoreConsole = TRUE)
# dev.off()
# windows(record=T,width=15, height=5)
# par(mfrow= c(1,3))
# ulim_hh <- 1.2*max(c(meancomfoi_child1[4,sel], meancomfoi_child2[4,sel]),na.rm=T)
# plot(meancomfoi_child1[4,sel], lwd = 2, type = "l", main = "Household size 5", ylab = "Community FOI children", xlab = "Time", ylim = c(0, ulim_hh))
# lines(meancomfoi_child2[4,sel], lwd = 2,col="red")
# legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
# ulim_hh <- 1.2*max(c(meancomfoi_child1[5,sel], meancomfoi_child2[5,sel]),na.rm=T)
# plot(meancomfoi_child1[5,sel], lwd = 2, type = "l", main = "Household size >=6", ylab = "Community FOI children", xlab = "Time", ylim = c(0, ulim_hh))
# lines(meancomfoi_child2[5,sel], lwd = 2,col="red")
# legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
# ulim_hh <- 1.2*max(c(apply(comfoi_child1,2,mean,na.rm=T)[sel], apply(comfoi_child2,2,mean,na.rm=T)[sel]),na.rm=T)
# plot(apply(comfoi_child1,2,mean,na.rm=T)[sel], lwd = 2, type = "l", main = "Total", ylab = "Community FOI children", xlab = "Time", ylim = c(0, ulim_hh))
# lines(apply(comfoi_child2,2,mean,na.rm=T)[sel], lwd = 2,col="red")
# legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
# savePlot(filename = paste("comfoi_child_hhsize_mean2", "_", abbrev1, "_", abbrev2, name, ".jpg", sep=""), type = "jpg", restoreConsole = TRUE)
# dev.off()

# ## Community force of infection adults per household size per time step
# sampleSize <- 50
# comfoi_adult1_hhsize <- model1$comfoi_adult_hhsize[,,sel1]
# comfoi_adult2_hhsize <- model2$comfoi_adult_hhsize[,,sel2]
# ulim_hh <- max(c(comfoi_adult1_hhsize, comfoi_adult2_hhsize),na.rm=T)
# ## stacked plot
# sel = 1:timeSteps
# meancomfoi_adult1 = apply(comfoi_adult1_hhsize,c(1,2),mean,na.rm=T)
# meancomfoi_adult2 = apply(comfoi_adult2_hhsize,c(1,2),mean,na.rm=T)
# windows(record=T,width=15, height=5)
# par(mfrow= c(1,3))
# ulim_hh <- 1.2*max(c(meancomfoi_adult1[1,sel], meancomfoi_adult2[1,sel]),na.rm=T)
# plot(meancomfoi_adult1[1,sel], lwd = 2, type = "l", main = "Household size 2", ylab = "Community FOI adults", xlab = "Time", ylim = c(0, ulim_hh))
# lines(meancomfoi_adult2[1,sel], lwd = 2,col="red")
# legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
# ulim_hh <- 1.2*max(c(meancomfoi_adult1[2,sel], meancomfoi_adult2[2,sel]),na.rm=T)
# plot(meancomfoi_adult1[2,sel], lwd = 2, type = "l", main = "Household size 3", ylab = "Community FOI adults", xlab = "Time", ylim = c(0, ulim_hh))
# lines(meancomfoi_adult2[2,sel], lwd = 2,col="red")
# legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
# ulim_hh <- 1.2*max(c(meancomfoi_adult1[3,sel], meancomfoi_adult2[3,sel]),na.rm=T)
# plot(meancomfoi_adult1[3,sel], lwd = 2, type = "l", main = "Household size 4", ylab = "Community FOI adults", xlab = "Time", ylim = c(0, ulim_hh))
# lines(meancomfoi_adult2[3,sel], lwd = 2,col="red")
# legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
# savePlot(filename = paste("comfoi_adult_hhsize_mean1", "_", abbrev1, "_", abbrev2, name, ".jpg", sep=""), type = "jpg", restoreConsole = TRUE)
# dev.off()
# windows(record=T,width=15, height=5)
# par(mfrow= c(1,3))
# ulim_hh <- 1.2*max(c(meancomfoi_adult1[4,sel], meancomfoi_adult2[4,sel]),na.rm=T)
# plot(meancomfoi_adult1[4,sel], lwd = 2, type = "l", main = "Household size 5", ylab = "Community FOI adults", xlab = "Time", ylim = c(0, ulim_hh))
# lines(meancomfoi_adult2[4,sel], lwd = 2,col="red")
# legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
# ulim_hh <- 1.2*max(c(meancomfoi_adult1[5,sel], meancomfoi_adult2[5,sel]),na.rm=T)
# plot(meancomfoi_adult1[5,sel], lwd = 2, type = "l", main = "Household size >=6", ylab = "Community FOI adults", xlab = "Time", ylim = c(0, ulim_hh))
# lines(meancomfoi_adult2[5,sel], lwd = 2,col="red")
# legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
# ulim_hh <- 1.2*max(c(apply(comfoi_adult1,2,mean,na.rm=T)[sel], apply(comfoi_adult2,2,mean,na.rm=T)[sel]),na.rm=T)
# plot(apply(comfoi_adult1,2,mean,na.rm=T)[sel], lwd = 2, type = "l", main = "Total", ylab = "Community FOI adults", xlab = "Time", ylim = c(0, ulim_hh))
# lines(apply(comfoi_adult2,2,mean,na.rm=T)[sel], lwd = 2,col="red")
# legend("topright",lty=c(1,1),col=c("black","red"),c(abbrev1,abbrev2))
# savePlot(filename = paste("comfoi_adult_hhsize_mean2", "_", abbrev1, "_", abbrev2, name, ".jpg", sep=""), type = "jpg", restoreConsole = TRUE)
# dev.off()



####################################################################
# Plotting random mixing with and without density correction and ERGM
####################################################################

sel3 = model3$extinction == FALSE

# Mean proportion infected per household size
hhPropInfected_hhsize1 <- model1$hhPropInfected_hhsize[sel1, ]
hhPropInfected_hhsize2 <- model2$hhPropInfected_hhsize[sel2, ]
hhPropInfected_hhsize3 <- model3$hhPropInfected_hhsize[sel3, ]
hhPropInfected1 <- model1$hhPropInfected[sel1]
hhPropInfected2 <- model2$hhPropInfected[sel2]
hhPropInfected3 <- model3$hhPropInfected[sel3]
# Summary
apply(hhPropInfected_hhsize1, 2, summary)
apply(hhPropInfected_hhsize2, 2, summary)
apply(hhPropInfected_hhsize3, 2, summary)
llim <- min(c(hhPropInfected_hhsize1, hhPropInfected_hhsize2, hhPropInfected_hhsize3))
# Figure: all categories
#par(mfrow=c(2,3))
windows(record=T,width=15, height=5)
par(mfrow= c(1,3))
boxplot(hhPropInfected_hhsize3[,1], hhPropInfected_hhsize1[,1], hhPropInfected_hhsize2[,1], main = "Household size 2", names = c(abbrev3,abbrev1,abbrev2)
        , ylab = "Household attack rate", boxwex = 0.6, cex.main = 1, notch = TRUE, ylim = c(llim,1))
boxplot(hhPropInfected_hhsize3[,2], hhPropInfected_hhsize1[,2], hhPropInfected_hhsize2[,2], main = "Household size 3", names = c(abbrev3,abbrev1,abbrev2)
        , ylab = "Household attack rate", boxwex = 0.6, cex.main = 1, notch = TRUE, ylim = c(llim,1))
boxplot(hhPropInfected_hhsize3[,3], hhPropInfected_hhsize1[,3], hhPropInfected_hhsize2[,3], main = "Household size 4", names = c(abbrev3,abbrev1,abbrev2)
        , ylab = "Household attack rate", boxwex = 0.6, cex.main = 1, notch = TRUE, ylim = c(llim,1))
savePlot(filename = paste("hhPropInfected1_comp3", "_", abbrev1, "_", abbrev2, name, ".jpg", sep=""), type = "jpg", restoreConsole = TRUE)
dev.off()
windows(record=T,width=15, height=5)
par(mfrow= c(1,3))
boxplot(hhPropInfected_hhsize3[,4], hhPropInfected_hhsize1[,4], hhPropInfected_hhsize2[,4], main = "Household size 5", names = c(abbrev3,abbrev1,abbrev2)
        , ylab = "Household attack rate", boxwex = 0.6, cex.main = 1, notch = TRUE, ylim = c(llim,1))
boxplot(hhPropInfected_hhsize3[,5], hhPropInfected_hhsize1[,5], hhPropInfected_hhsize2[,5], main = "Household size >=6", names = c(abbrev3,abbrev1,abbrev2)
        , ylab = "Household attack rate", boxwex = 0.6, cex.main = 1, notch = TRUE, ylim = c(llim,1))
boxplot(hhPropInfected3, hhPropInfected1, hhPropInfected2, main = "Total", names = c(abbrev3,abbrev1, abbrev2)
        , ylab = "Household attack rate", boxwex = 0.6, cex.main = 1, notch = TRUE, ylim = c(llim,1))
savePlot(filename = paste("hhPropInfected2_comp3", "_", abbrev1, "_", abbrev2, name, ".jpg", sep=""), type = "jpg", restoreConsole = TRUE)
dev.off()


####################################################################
# Plot the distribution of number of contacts per HH size
####################################################################

range <- c("2","3","4","5",">=6")
range2 <- c(0:14,">=15")
hh_id <- HH_sim_week[[1]] %v% "hh_id"
hh_size <- HH_sim_week[[1]] %v% "hh_size"
hh_id_unique <- unique(hh_id)
hhSize <- hh_size[!duplicated(hh_id)]
hh_contacts = matrix(NA,length(hh_id_unique),1000)
hh_contacts_factor = list()
hhSize_factor <- cut(hhSize, c(2:6,10), labels = range, right = FALSE)
hh_contacts_hhsize <- array(NA,c(length(range),length(range2),1000))

for (j in 1:1000){
  HH_network = HH_sim_week[[j]]
  for (i in 1:length(hh_id_unique)){
    sel = hh_id == hh_id_unique[i]
    hh_contacts[i,j] <- sum(HH_network[sel,sel])/2
  }
  hh_contacts_factor[[j]] = cut(hh_contacts[,j], c(0:15,21), right = FALSE,labels=range2)
  for (i in 1:length(range)){
    hh_contacts_hhsize[i,,j] <- table(hh_contacts_factor[[j]][hhSize_factor == range[i]])
  }
}

contacts = c(sapply(range2,rep,sum(sel2)))
dat2 = data.frame(count=c(t(hh_contacts_hhsize[1,,sel2])),contacts=contacts)
dat2$contacts = factor(dat2$contacts,levels(dat2$contacts)[c(2:3,9:length(range2),4:8,1)])
dat3 = data.frame(count=c(t(hh_contacts_hhsize[2,,sel2])),contacts=contacts)
dat3$contacts = factor(dat3$contacts,levels(dat3$contacts)[c(2:3,9:length(range2),4:8,1)])
dat4 = data.frame(count=c(t(hh_contacts_hhsize[3,,sel2])),contacts=contacts)
dat4$contacts = factor(dat4$contacts,levels(dat4$contacts)[c(2:3,9:length(range2),4:8,1)])
dat5 = data.frame(count=c(t(hh_contacts_hhsize[4,,sel2])),contacts=contacts)
dat5$contacts = factor(dat5$contacts,levels(dat5$contacts)[c(2:3,9:length(range2),4:8,1)])
dat6 = data.frame(count=c(t(hh_contacts_hhsize[5,,sel2])),contacts=contacts)
dat6$contacts = factor(dat6$contacts,levels(dat6$contacts)[c(2:3,9:length(range2),4:8,1)])

windows(record=T,width=9, height=5)
par(mfrow= c(1,1))
boxplot(count~contacts,data=dat2, main = "Household size 2",xlab="Number of contacts", ylab = "Frequency", boxwex = 0.6, cex.main = 1, notch = F,xaxt="n")
axis(1,at=seq(1,length(range2),1),labels=range2)       
savePlot(filename = paste("distribution_contacts_weeknetwork_HHsize2.eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off()

windows(record=T,width=9, height=5)
par(mfrow= c(1,1))
boxplot(count~contacts,data=dat3, main = "Household size 3",xlab="Number of contacts", ylab = "Frequency", boxwex = 0.6, cex.main = 1, notch = F,xaxt="n")
axis(1,at=seq(1,length(range2),1),labels=range2)       
savePlot(filename = paste("distribution_contacts_weeknetwork_HHsize3.eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off()

windows(record=T,width=9, height=5)
par(mfrow= c(1,1))
boxplot(count~contacts,data=dat4, main = "Household size 4",xlab="Number of contacts", ylab = "Frequency", boxwex = 0.6, cex.main = 1, notch = F,xaxt="n")
axis(1,at=seq(1,length(range2),1),labels=range2)       
savePlot(filename = paste("distribution_contacts_weeknetwork_HHsize4.eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off()

windows(record=T,width=9, height=5)
par(mfrow= c(1,1))
boxplot(count~contacts,data=dat5, main = "Household size 5",xlab="Number of contacts", ylab = "Frequency", boxwex = 0.6, cex.main = 1, notch = F,xaxt="n")
axis(1,at=seq(1,length(range2),1),labels=range2)       
savePlot(filename = paste("distribution_contacts_weeknetwork_HHsize5.eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off()

windows(record=T,width=9, height=5)
par(mfrow= c(1,1))
boxplot(count~contacts,data=dat6, main = "Household size >=6",xlab="Number of contacts", ylab = "Frequency", boxwex = 0.6, cex.main = 1, notch = F,xaxt="n")
axis(1,at=seq(1,length(range2),1),labels=range2)       
savePlot(filename = paste("distribution_contacts_weeknetwork_HHsize6.eps", sep=""), type = "eps", restoreConsole = TRUE)
dev.off()




